-- noinspection SqlDialectInspectionForFile
-- noinspection SqlNoDataSourceInspectionForFile
INSERT INTO crams_forcode (id, code, description) VALUES (1, '01', 'Mathematical Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (2, '02', 'Physical Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (3, '03', 'Chemical Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (4, '04', 'Earth Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (5, '05', 'Environmental Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (6, '06', 'Biological Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (7, '07', 'Agricultural and Veterinary Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (8, '08', 'Information and Computing Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (9, '09', 'Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (10, '10', 'Technology');
INSERT INTO crams_forcode (id, code, description) VALUES (11, '11', 'Medical and Health Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (12, '12', 'Built Environment and Design');
INSERT INTO crams_forcode (id, code, description) VALUES (13, '13', 'Education');
INSERT INTO crams_forcode (id, code, description) VALUES (14, '14', 'Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (15, '15', 'Commerce, Management, Tourism and Services');
INSERT INTO crams_forcode (id, code, description) VALUES (16, '16', 'Studies in Human Society');
INSERT INTO crams_forcode (id, code, description) VALUES (17, '17', 'Psychology and Cognitive Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (18, '18', 'Law and Legal Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (19, '19', 'Studies in Creative Arts and Writing');
INSERT INTO crams_forcode (id, code, description) VALUES (20, '20', 'Language, Communication and Culture');
INSERT INTO crams_forcode (id, code, description) VALUES (21, '21', 'History and Archaeology');
INSERT INTO crams_forcode (id, code, description) VALUES (22, '22', 'Philosophy and Religious Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (23, '0101', 'Pure Mathematics');
INSERT INTO crams_forcode (id, code, description) VALUES (24, '0102', 'Applied Mathematics');
INSERT INTO crams_forcode (id, code, description) VALUES (25, '0103', 'Numerical and Computational Mathematics');
INSERT INTO crams_forcode (id, code, description) VALUES (26, '0104', 'Statistics');
INSERT INTO crams_forcode (id, code, description) VALUES (27, '0105', 'Mathematical Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (28, '0199', 'Other Mathematical Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (29, '0201', 'Astronomical and Space Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (30, '0202', 'Atomic, Molecular, Nuclear, Particle and Plasma Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (31, '0203', 'Classical Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (32, '0204', 'Condensed Matter Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (33, '0205', 'Optical Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (34, '0206', 'Quantum Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (35, '0299', 'Other Physical Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (36, '0301', 'Analytical Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (37, '0302', 'Inorganic Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (38, '0303', 'Macromolecular and Materials Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (39, '0304', 'Medicinal and Biomolecular Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (40, '0305', 'Organic Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (41, '0306', 'Physical Chemistry (Incl. Structural)');
INSERT INTO crams_forcode (id, code, description) VALUES (42, '0307', 'Theoretical and Computational Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (43, '0399', 'Other Chemical Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (44, '0401', 'Atmospheric Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (45, '0402', 'Geochemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (46, '0403', 'Geology');
INSERT INTO crams_forcode (id, code, description) VALUES (47, '0404', 'Geophysics');
INSERT INTO crams_forcode (id, code, description) VALUES (48, '0405', 'Oceanography');
INSERT INTO crams_forcode (id, code, description) VALUES (49, '0406', 'Physical Geography and Environmental Geoscience');
INSERT INTO crams_forcode (id, code, description) VALUES (50, '0499', 'Other Earth Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (51, '0501', 'Ecological Applications');
INSERT INTO crams_forcode (id, code, description) VALUES (52, '0502', 'Environmental Science and Management');
INSERT INTO crams_forcode (id, code, description) VALUES (53, '0503', 'Soil Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (54, '0599', 'Other Environmental Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (55, '0601', 'Biochemistry and Cell Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (56, '0602', 'Ecology');
INSERT INTO crams_forcode (id, code, description) VALUES (57, '0603', 'Evolutionary Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (58, '0604', 'Genetics');
INSERT INTO crams_forcode (id, code, description) VALUES (59, '0605', 'Microbiology');
INSERT INTO crams_forcode (id, code, description) VALUES (60, '0606', 'Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (61, '0607', 'Plant Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (62, '0608', 'Zoology');
INSERT INTO crams_forcode (id, code, description) VALUES (63, '0699', 'Other Biological Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (64, '0701', 'Agriculture, Land and Farm Management');
INSERT INTO crams_forcode (id, code, description) VALUES (65, '0702', 'Animal Production');
INSERT INTO crams_forcode (id, code, description) VALUES (66, '0703', 'Crop and Pasture Production');
INSERT INTO crams_forcode (id, code, description) VALUES (67, '0704', 'Fisheries Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (68, '0705', 'Forestry Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (69, '0706', 'Horticultural Production');
INSERT INTO crams_forcode (id, code, description) VALUES (70, '0707', 'Veterinary Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (71, '0799', 'Other Agricultural and Veterinary Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (72, '0801', 'Artificial Intelligence and Image Processing');
INSERT INTO crams_forcode (id, code, description) VALUES (73, '0802', 'Computation Theory and Mathematics');
INSERT INTO crams_forcode (id, code, description) VALUES (74, '0803', 'Computer Software');
INSERT INTO crams_forcode (id, code, description) VALUES (75, '0804', 'Data Format');
INSERT INTO crams_forcode (id, code, description) VALUES (76, '0805', 'Distributed Computing');
INSERT INTO crams_forcode (id, code, description) VALUES (77, '0806', 'Information Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (78, '0807', 'Library and Information Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (79, '0899', 'Other Information and Computing Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (80, '0901', 'Aerospace Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (81, '0902', 'Automotive Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (82, '0903', 'Biomedical Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (83, '0904', 'Chemical Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (84, '0905', 'Civil Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (85, '0906', 'Electrical and Electronic Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (86, '0907', 'Environmental Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (87, '0908', 'Food Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (88, '0909', 'Geomatic Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (89, '0910', 'Manufacturing Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (90, '0911', 'Maritime Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (91, '0912', 'Materials Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (92, '0913', 'Mechanical Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (93, '0914', 'Resources Engineering and Extractive Metallurgy');
INSERT INTO crams_forcode (id, code, description) VALUES (94, '0915', 'Interdisciplinary Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (95, '0999', 'Other Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (96, '1001', 'Agricultural Biotechnology');
INSERT INTO crams_forcode (id, code, description) VALUES (97, '1002', 'Environmental Biotechnology');
INSERT INTO crams_forcode (id, code, description) VALUES (98, '1003', 'Industrial Biotechnology');
INSERT INTO crams_forcode (id, code, description) VALUES (99, '1004', 'Medical Biotechnology');
INSERT INTO crams_forcode (id, code, description) VALUES (100, '1005', 'Communications Technologies');
INSERT INTO crams_forcode (id, code, description) VALUES (101, '1006', 'Computer Hardware');
INSERT INTO crams_forcode (id, code, description) VALUES (102, '1007', 'Nanotechnology');
INSERT INTO crams_forcode (id, code, description) VALUES (103, '1099', 'Other Technology');
INSERT INTO crams_forcode (id, code, description) VALUES (104, '1101', 'Medical Biochemistry and Metabolomics');
INSERT INTO crams_forcode (id, code, description) VALUES (105, '1102', 'Cardiorespiratory Medicine and Haematology');
INSERT INTO crams_forcode (id, code, description) VALUES (106, '1103', 'Clinical Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (107, '1104', 'Complementary and Alternative Medicine');
INSERT INTO crams_forcode (id, code, description) VALUES (108, '1105', 'Dentistry');
INSERT INTO crams_forcode (id, code, description) VALUES (109, '1106', 'Human Movement and Sports Science');
INSERT INTO crams_forcode (id, code, description) VALUES (110, '1107', 'Immunology');
INSERT INTO crams_forcode (id, code, description) VALUES (111, '1108', 'Medical Microbiology');
INSERT INTO crams_forcode (id, code, description) VALUES (112, '1109', 'Neurosciences');
INSERT INTO crams_forcode (id, code, description) VALUES (113, '1110', 'Nursing');
INSERT INTO crams_forcode (id, code, description) VALUES (114, '1111', 'Nutrition and Dietetics');
INSERT INTO crams_forcode (id, code, description) VALUES (115, '1112', 'Oncology and Carcinogenesis');
INSERT INTO crams_forcode (id, code, description) VALUES (116, '1113', 'Ophthalmology and Optometry');
INSERT INTO crams_forcode (id, code, description) VALUES (117, '1114', 'Paediatrics and Reproductive Medicine');
INSERT INTO crams_forcode (id, code, description) VALUES (118, '1115', 'Pharmacology and Pharmaceutical Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (119, '1116', 'Medical Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (120, '1117', 'Public Health and Health Services');
INSERT INTO crams_forcode (id, code, description) VALUES (121, '1199', 'Other Medical and Health Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (122, '1201', 'Architecture');
INSERT INTO crams_forcode (id, code, description) VALUES (123, '1202', 'Building');
INSERT INTO crams_forcode (id, code, description) VALUES (124, '1203', 'Design Practice and Management');
INSERT INTO crams_forcode (id, code, description) VALUES (125, '1204', 'Engineering Design');
INSERT INTO crams_forcode (id, code, description) VALUES (126, '1205', 'Urban and Regional Planning');
INSERT INTO crams_forcode (id, code, description) VALUES (127, '1299', 'Other Built Environment and Design');
INSERT INTO crams_forcode (id, code, description) VALUES (128, '1301', 'Education Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (129, '1302', 'Curriculum and Pedagogy');
INSERT INTO crams_forcode (id, code, description) VALUES (130, '1303', 'Specialist Studies in Education');
INSERT INTO crams_forcode (id, code, description) VALUES (131, '1399', 'Other Education');
INSERT INTO crams_forcode (id, code, description) VALUES (132, '1401', 'Economic Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (133, '1402', 'Applied Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (134, '1403', 'Econometrics');
INSERT INTO crams_forcode (id, code, description) VALUES (135, '1499', 'Other Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (136, '1501', 'Accounting, Auditing and Accountability');
INSERT INTO crams_forcode (id, code, description) VALUES (137, '1502', 'Banking, Finance and Investment');
INSERT INTO crams_forcode (id, code, description) VALUES (138, '1503', 'Business and Management');
INSERT INTO crams_forcode (id, code, description) VALUES (139, '1504', 'Commercial Services');
INSERT INTO crams_forcode (id, code, description) VALUES (140, '1505', 'Marketing');
INSERT INTO crams_forcode (id, code, description) VALUES (141, '1506', 'Tourism');
INSERT INTO crams_forcode (id, code, description) VALUES (142, '1507', 'Transportation and Freight Services');
INSERT INTO crams_forcode (id, code, description) VALUES (143, '1599', 'Other Commerce, Management, Tourism and Services');
INSERT INTO crams_forcode (id, code, description) VALUES (144, '1601', 'Anthropology');
INSERT INTO crams_forcode (id, code, description) VALUES (145, '1602', 'Criminology');
INSERT INTO crams_forcode (id, code, description) VALUES (146, '1603', 'Demography');
INSERT INTO crams_forcode (id, code, description) VALUES (147, '1604', 'Human Geography');
INSERT INTO crams_forcode (id, code, description) VALUES (148, '1605', 'Policy and Administration');
INSERT INTO crams_forcode (id, code, description) VALUES (149, '1606', 'Political Science');
INSERT INTO crams_forcode (id, code, description) VALUES (150, '1607', 'Social Work');
INSERT INTO crams_forcode (id, code, description) VALUES (151, '1608', 'Sociology');
INSERT INTO crams_forcode (id, code, description) VALUES (152, '1699', 'Other Studies in Human Society');
INSERT INTO crams_forcode (id, code, description) VALUES (153, '1701', 'Psychology');
INSERT INTO crams_forcode (id, code, description) VALUES (154, '1702', 'Cognitive Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (155, '1799', 'Other Psychology and Cognitive Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (156, '1801', 'Law');
INSERT INTO crams_forcode (id, code, description) VALUES (157, '1802', 'Maori Law');
INSERT INTO crams_forcode (id, code, description) VALUES (158, '1899', 'Other law and Legal Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (159, '1901', 'Art Theory and Criticism');
INSERT INTO crams_forcode (id, code, description) VALUES (160, '1902', 'Film, Television and Digital Media');
INSERT INTO crams_forcode (id, code, description) VALUES (161, '1903', 'Journalism and Professional Writing');
INSERT INTO crams_forcode (id, code, description) VALUES (162, '1904', 'Performing Arts and Creative Writing');
INSERT INTO crams_forcode (id, code, description) VALUES (163, '1905', 'Visual Arts and Crafts');
INSERT INTO crams_forcode (id, code, description) VALUES (164, '1999', 'Other Studies in Creative Arts and Writing');
INSERT INTO crams_forcode (id, code, description) VALUES (165, '2001', 'Communication and Media Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (166, '2002', 'Cultural Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (167, '2003', 'Language Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (168, '2004', 'Linguistics');
INSERT INTO crams_forcode (id, code, description) VALUES (169, '2005', 'Literary Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (170, '2099', 'Other Language, Communication and Culture');
INSERT INTO crams_forcode (id, code, description) VALUES (171, '2101', 'Archaeology');
INSERT INTO crams_forcode (id, code, description) VALUES (172, '2102', 'Curatorial and Related Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (173, '2103', 'Historical Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (174, '2199', 'Other History and Archaeology');
INSERT INTO crams_forcode (id, code, description) VALUES (175, '2201', 'Applied Ethics');
INSERT INTO crams_forcode (id, code, description) VALUES (176, '2202', 'History and Philosophy of Specific Fields');
INSERT INTO crams_forcode (id, code, description) VALUES (177, '2203', 'Philosophy');
INSERT INTO crams_forcode (id, code, description) VALUES (178, '2204', 'Religion and Religious Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (179, '2299', 'Other Philosophy and Religious Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (180, '010101', 'Algebra and Number Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (181, '010102', 'Algebraic and Differential Geometry');
INSERT INTO crams_forcode (id, code, description) VALUES (182, '010103', 'Category Theory, K Theory, Homological Algebra');
INSERT INTO crams_forcode (id, code, description) VALUES (183, '010104', 'Combinatorics and Discrete Mathematics (excl. Physical Combinatorics)');
INSERT INTO crams_forcode (id, code, description) VALUES (184, '010105', 'Group Theory and Generalisations');
INSERT INTO crams_forcode (id, code, description) VALUES (185, '010106', 'Lie Groups, Harmonic and Fourier Analysis');
INSERT INTO crams_forcode (id, code, description) VALUES (186, '010107', 'Mathematical Logic, Set Theory, Lattices and Universal Algebra');
INSERT INTO crams_forcode (id, code, description) VALUES (187, '010108', 'Operator Algebras and Functional Analysis');
INSERT INTO crams_forcode (id, code, description) VALUES (188, '010109', 'Ordinary Differential Equations, Difference Equations and Dynamical Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (189, '010110', 'Partial Differential Equations');
INSERT INTO crams_forcode (id, code, description) VALUES (190, '010111', 'Real and Complex Functions (incl. Several Variables)');
INSERT INTO crams_forcode (id, code, description) VALUES (191, '010112', 'Topology');
INSERT INTO crams_forcode (id, code, description) VALUES (192, '010199', 'Pure Mathematics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (193, '010201', 'Approximation Theory and Asymptotic Methods');
INSERT INTO crams_forcode (id, code, description) VALUES (194, '010202', 'Biological Mathematics');
INSERT INTO crams_forcode (id, code, description) VALUES (195, '010203', 'Calculus of Variations, Systems Theory and Control Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (196, '010204', 'Dynamical Systems in Applications');
INSERT INTO crams_forcode (id, code, description) VALUES (197, '010205', 'Financial Mathematics');
INSERT INTO crams_forcode (id, code, description) VALUES (198, '010206', 'Operations Research');
INSERT INTO crams_forcode (id, code, description) VALUES (199, '010207', 'Theoretical and Applied Mechanics');
INSERT INTO crams_forcode (id, code, description) VALUES (200, '010299', 'Applied Mathematics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (201, '010301', 'Numerical Analysis');
INSERT INTO crams_forcode (id, code, description) VALUES (202, '010302', 'Numerical Solution of Differential and Integral Equations');
INSERT INTO crams_forcode (id, code, description) VALUES (203, '010303', 'Optimisation');
INSERT INTO crams_forcode (id, code, description) VALUES (204, '010399', 'Numerical and Computational Mathematics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (205, '010401', 'Applied Statistics');
INSERT INTO crams_forcode (id, code, description) VALUES (206, '010402', 'Biostatistics');
INSERT INTO crams_forcode (id, code, description) VALUES (207, '010403', 'Forensic Statistics');
INSERT INTO crams_forcode (id, code, description) VALUES (208, '010404', 'Probability Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (209, '010405', 'Statistical Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (210, '010406', 'Stochastic Analysis and Modelling');
INSERT INTO crams_forcode (id, code, description) VALUES (211, '010499', 'Statistics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (212, '010501', 'Algebraic Structures in Mathematical Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (213, '010502', 'Integrable Systems (Classical and Quantum)');
INSERT INTO crams_forcode (id, code, description) VALUES (214, '010503', 'Mathematical Aspects of Classical Mechanics, Quantum Mechanics and Quantum Information Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (215, '010504', 'Mathematical Aspects of General Relativity');
INSERT INTO crams_forcode (id, code, description) VALUES (216, '010505', 'Mathematical Aspects of Quantum and Conformal Field Theory, Quantum Gravity and String Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (217, '010506', 'Statistical Mechanics, Physical Combinatorics and Mathematical Aspects of Condensed Matter');
INSERT INTO crams_forcode (id, code, description) VALUES (218, '010599', 'Mathematical Physics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (322, '040104', 'Climate Change Processes');
INSERT INTO crams_forcode (id, code, description) VALUES (219, '019999', 'Mathematical Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (220, '020101', 'Astrobiology');
INSERT INTO crams_forcode (id, code, description) VALUES (221, '020102', 'Astronomical and Space Instrumentation');
INSERT INTO crams_forcode (id, code, description) VALUES (222, '020103', 'Cosmology and Extragalactic Astronomy');
INSERT INTO crams_forcode (id, code, description) VALUES (223, '020104', 'Galactic Astronomy');
INSERT INTO crams_forcode (id, code, description) VALUES (224, '020105', 'General Relativity and Gravitational Waves');
INSERT INTO crams_forcode (id, code, description) VALUES (225, '020106', 'High Energy Astrophysics; Cosmic Rays');
INSERT INTO crams_forcode (id, code, description) VALUES (226, '020107', 'Mesospheric, Ionospheric and Magnetospheric Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (227, '020108', 'Planetary Science (excl. Extraterrestrial Geology)');
INSERT INTO crams_forcode (id, code, description) VALUES (228, '020109', 'Space and Solar Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (229, '020110', 'Stellar Astronomy and Planetary Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (230, '020199', 'Astronomical and Space Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (231, '020201', 'Atomic and Molecular Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (232, '020202', 'Nuclear Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (233, '020203', 'Particle Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (234, '020204', 'Plasma Physics; Fusion Plasmas; Electrical Discharges');
INSERT INTO crams_forcode (id, code, description) VALUES (235, '020299', 'Atomic, Molecular, Nuclear, Particle and Plasma Physics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (236, '020301', 'Acoustics and Acoustical Devices; Waves');
INSERT INTO crams_forcode (id, code, description) VALUES (237, '020302', 'Electrostatics and Electrodynamics');
INSERT INTO crams_forcode (id, code, description) VALUES (238, '020303', 'Fluid Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (239, '020304', 'Thermodynamics and Statistical Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (240, '020399', 'Classical Physics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (241, '020401', 'Condensed Matter Characterisation Technique Development');
INSERT INTO crams_forcode (id, code, description) VALUES (242, '020402', 'Condensed Matter Imaging');
INSERT INTO crams_forcode (id, code, description) VALUES (243, '020403', 'Condensed Matter Modelling and Density Functional Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (244, '020404', 'Electronic and Magnetic Properties of Condensed Matter; Superconductivity');
INSERT INTO crams_forcode (id, code, description) VALUES (245, '020405', 'Soft Condensed Matter');
INSERT INTO crams_forcode (id, code, description) VALUES (246, '020406', 'Surfaces and Structural Properties of Condensed Matter');
INSERT INTO crams_forcode (id, code, description) VALUES (247, '020499', 'Condensed Matter Physics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (248, '020501', 'Classical and Physical Optics');
INSERT INTO crams_forcode (id, code, description) VALUES (249, '020502', 'Lasers and Quantum Electronics');
INSERT INTO crams_forcode (id, code, description) VALUES (250, '020503', 'Nonlinear Optics and Spectroscopy');
INSERT INTO crams_forcode (id, code, description) VALUES (251, '020504', 'Photonics, Optoelectronics and Optical Communications');
INSERT INTO crams_forcode (id, code, description) VALUES (252, '020599', 'Optical Physics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (253, '020601', 'Degenerate Quantum Gases and Atom Optics');
INSERT INTO crams_forcode (id, code, description) VALUES (254, '020602', 'Field Theory and String Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (255, '020603', 'Quantum Information, Computation and Communication');
INSERT INTO crams_forcode (id, code, description) VALUES (256, '020604', 'Quantum Optics');
INSERT INTO crams_forcode (id, code, description) VALUES (257, '020699', 'Quantum Physics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (258, '029901', 'Biological Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (259, '029902', 'Complex Physical Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (260, '029903', 'Medical Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (261, '029904', 'Synchrotrons; Accelerators; Instruments and Techniques');
INSERT INTO crams_forcode (id, code, description) VALUES (262, '029999', 'Physical Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (263, '030101', 'Analytical Spectrometry');
INSERT INTO crams_forcode (id, code, description) VALUES (264, '030102', 'Electroanalytical Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (265, '030103', 'Flow Analysis');
INSERT INTO crams_forcode (id, code, description) VALUES (266, '030104', 'Immunological and Bioassay Methods');
INSERT INTO crams_forcode (id, code, description) VALUES (267, '030105', 'Instrumental Methods (excl. Immunological and Bioassay Methods)');
INSERT INTO crams_forcode (id, code, description) VALUES (268, '030106', 'Quality Assurance, Chemometrics, Traceability and Metrological Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (269, '030107', 'Sensor Technology (Chemical aspects)');
INSERT INTO crams_forcode (id, code, description) VALUES (270, '030108', 'Separation Science');
INSERT INTO crams_forcode (id, code, description) VALUES (271, '030199', 'Analytical Chemistry not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (272, '030201', 'Bioinorganic Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (273, '030202', 'f-Block Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (274, '030203', 'Inorganic Green Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (275, '030204', 'Main Group Metal Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (276, '030205', 'Non-metal Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (277, '030206', 'Solid State Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (278, '030207', 'Transition Metal Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (279, '030299', 'Inorganic Chemistry not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (280, '030301', 'Chemical Characterisation of Materials');
INSERT INTO crams_forcode (id, code, description) VALUES (281, '030302', 'Nanochemistry and Supramolecular Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (282, '030303', 'Optical Properties of Materials');
INSERT INTO crams_forcode (id, code, description) VALUES (283, '030304', 'Physical Chemistry of Materials');
INSERT INTO crams_forcode (id, code, description) VALUES (284, '030305', 'Polymerisation Mechanisms');
INSERT INTO crams_forcode (id, code, description) VALUES (285, '030306', 'Synthesis of Materials');
INSERT INTO crams_forcode (id, code, description) VALUES (286, '030307', 'Theory and Design of Materials');
INSERT INTO crams_forcode (id, code, description) VALUES (287, '030399', 'Macromolecular and Materials Chemistry not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (288, '030401', 'Biologically Active Molecules');
INSERT INTO crams_forcode (id, code, description) VALUES (289, '030402', 'Biomolecular Modelling and Design');
INSERT INTO crams_forcode (id, code, description) VALUES (290, '030403', 'Characterisation of Biological Macromolecules');
INSERT INTO crams_forcode (id, code, description) VALUES (291, '030404', 'Cheminformatics and Quantitative Structure-Activity Relationships');
INSERT INTO crams_forcode (id, code, description) VALUES (292, '030405', 'Molecular Medicine');
INSERT INTO crams_forcode (id, code, description) VALUES (293, '030406', 'Proteins and Peptides');
INSERT INTO crams_forcode (id, code, description) VALUES (294, '030499', 'Medicinal and Biomolecular Chemistry not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (295, '030501', 'Free Radical Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (296, '030502', 'Natural Products Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (297, '030503', 'Organic Chemical Synthesis');
INSERT INTO crams_forcode (id, code, description) VALUES (298, '030504', 'Organic Green Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (299, '030505', 'Physical Organic Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (300, '030599', 'Organic Chemistry not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (301, '030601', 'Catalysis and Mechanisms of Reactions');
INSERT INTO crams_forcode (id, code, description) VALUES (302, '030602', 'Chemical Thermodynamics and Energetics');
INSERT INTO crams_forcode (id, code, description) VALUES (303, '030603', 'Colloid and Surface Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (304, '030604', 'Electrochemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (305, '030605', 'Solution Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (306, '030606', 'Structural Chemistry and Spectroscopy');
INSERT INTO crams_forcode (id, code, description) VALUES (307, '030607', 'Transport Properties and Non-Equilibrium Processes');
INSERT INTO crams_forcode (id, code, description) VALUES (308, '030699', 'Physical Chemistry not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (309, '030701', 'Quantum Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (310, '030702', 'Radiation and Matter');
INSERT INTO crams_forcode (id, code, description) VALUES (311, '030703', 'Reaction Kinetics and Dynamics');
INSERT INTO crams_forcode (id, code, description) VALUES (312, '030704', 'Statistical Mechanics in Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (313, '030799', 'Theoretical and Computational Chemistry not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (314, '039901', 'Environmental Chemistry (incl. Atmospheric Chemistry)');
INSERT INTO crams_forcode (id, code, description) VALUES (315, '039902', 'Forensic Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (316, '039903', 'Industrial Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (317, '039904', 'Organometallic Chemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (318, '039999', 'Chemical Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (319, '040101', 'Atmospheric Aerosols');
INSERT INTO crams_forcode (id, code, description) VALUES (320, '040102', 'Atmospheric Dynamics');
INSERT INTO crams_forcode (id, code, description) VALUES (321, '040103', 'Atmospheric Radiation');
INSERT INTO crams_forcode (id, code, description) VALUES (323, '040105', 'Climatology (excl. Climate Change Processes)');
INSERT INTO crams_forcode (id, code, description) VALUES (324, '040106', 'Cloud Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (325, '040107', 'Meteorology');
INSERT INTO crams_forcode (id, code, description) VALUES (326, '040108', 'Tropospheric and Stratospheric Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (327, '040199', 'Atmospheric Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (328, '040201', 'Exploration Geochemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (329, '040202', 'Inorganic Geochemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (330, '040203', 'Isotope Geochemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (331, '040204', 'Organic Geochemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (332, '040299', 'Geochemistry not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (333, '040301', 'Basin Analysis');
INSERT INTO crams_forcode (id, code, description) VALUES (334, '040302', 'Extraterrestrial Geology');
INSERT INTO crams_forcode (id, code, description) VALUES (335, '040303', 'Geochronology');
INSERT INTO crams_forcode (id, code, description) VALUES (336, '040304', 'Igneous and Metamorphic Petrology');
INSERT INTO crams_forcode (id, code, description) VALUES (337, '040305', 'Marine Geoscience');
INSERT INTO crams_forcode (id, code, description) VALUES (338, '040306', 'Mineralogy and Crystallography');
INSERT INTO crams_forcode (id, code, description) VALUES (339, '040307', 'Ore Deposit Petrology');
INSERT INTO crams_forcode (id, code, description) VALUES (340, '040308', 'Palaeontology (incl. Palynology)');
INSERT INTO crams_forcode (id, code, description) VALUES (341, '040309', 'Petroleum and Coal Geology');
INSERT INTO crams_forcode (id, code, description) VALUES (342, '040310', 'Sedimentology');
INSERT INTO crams_forcode (id, code, description) VALUES (343, '040311', 'Stratigraphy (incl. Biostratigraphy and Sequence Stratigraphy)');
INSERT INTO crams_forcode (id, code, description) VALUES (344, '040312', 'Structural Geology');
INSERT INTO crams_forcode (id, code, description) VALUES (345, '040313', 'Tectonics');
INSERT INTO crams_forcode (id, code, description) VALUES (346, '040314', 'Volcanology');
INSERT INTO crams_forcode (id, code, description) VALUES (347, '040399', 'Geology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (348, '040401', 'Electrical and Electromagnetic Methods in Geophysics');
INSERT INTO crams_forcode (id, code, description) VALUES (349, '040402', 'Geodynamics');
INSERT INTO crams_forcode (id, code, description) VALUES (350, '040403', 'Geophysical Fluid Dynamics');
INSERT INTO crams_forcode (id, code, description) VALUES (351, '040404', 'Geothermics and Radiometrics');
INSERT INTO crams_forcode (id, code, description) VALUES (352, '040405', 'Gravimetrics');
INSERT INTO crams_forcode (id, code, description) VALUES (353, '040406', 'Magnetism and Palaeomagnetism');
INSERT INTO crams_forcode (id, code, description) VALUES (354, '040407', 'Seismology and Seismic Exploration');
INSERT INTO crams_forcode (id, code, description) VALUES (355, '040499', 'Geophysics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (356, '040501', 'Biological Oceanography');
INSERT INTO crams_forcode (id, code, description) VALUES (357, '040502', 'Chemical Oceanography');
INSERT INTO crams_forcode (id, code, description) VALUES (358, '040503', 'Physical Oceanography');
INSERT INTO crams_forcode (id, code, description) VALUES (359, '040599', 'Oceanography not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (360, '040601', 'Geomorphology and Regolith and Landscape Evolution');
INSERT INTO crams_forcode (id, code, description) VALUES (361, '040602', 'Glaciology');
INSERT INTO crams_forcode (id, code, description) VALUES (362, '040603', 'Hydrogeology');
INSERT INTO crams_forcode (id, code, description) VALUES (363, '040604', 'Natural Hazards');
INSERT INTO crams_forcode (id, code, description) VALUES (364, '040605', 'Palaeoclimatology');
INSERT INTO crams_forcode (id, code, description) VALUES (365, '040606', 'Quaternary Environments');
INSERT INTO crams_forcode (id, code, description) VALUES (366, '040607', 'Surface Processes');
INSERT INTO crams_forcode (id, code, description) VALUES (367, '040608', 'Surfacewater Hydrology');
INSERT INTO crams_forcode (id, code, description) VALUES (368, '040699', 'Physical Geography and Environmental Geoscience not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (369, '049999', 'Earth Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (370, '050101', 'Ecological Impacts of Climate Change');
INSERT INTO crams_forcode (id, code, description) VALUES (371, '050102', 'Ecosystem Function');
INSERT INTO crams_forcode (id, code, description) VALUES (372, '050103', 'Invasive Species Ecology');
INSERT INTO crams_forcode (id, code, description) VALUES (373, '050104', 'Landscape Ecology');
INSERT INTO crams_forcode (id, code, description) VALUES (374, '050199', 'Ecological Applications not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (375, '050201', 'Aboriginal and Torres Strait Islander Environmental Knowledge');
INSERT INTO crams_forcode (id, code, description) VALUES (376, '050202', 'Conservation and Biodiversity');
INSERT INTO crams_forcode (id, code, description) VALUES (377, '050203', 'Environmental Education and Extension');
INSERT INTO crams_forcode (id, code, description) VALUES (378, '050204', 'Environmental Impact Assessment');
INSERT INTO crams_forcode (id, code, description) VALUES (379, '050205', 'Environmental Management');
INSERT INTO crams_forcode (id, code, description) VALUES (380, '050206', 'Environmental Monitoring');
INSERT INTO crams_forcode (id, code, description) VALUES (381, '050207', 'Environmental Rehabilitation (excl. Bioremediation)');
INSERT INTO crams_forcode (id, code, description) VALUES (382, '050208', 'Maori Environmental Knowledge');
INSERT INTO crams_forcode (id, code, description) VALUES (383, '050209', 'Natural Resource Management');
INSERT INTO crams_forcode (id, code, description) VALUES (384, '050210', 'Pacific Peoples Environmental Knowledge');
INSERT INTO crams_forcode (id, code, description) VALUES (385, '050211', 'Wildlife and Habitat Management');
INSERT INTO crams_forcode (id, code, description) VALUES (386, '050299', 'Environmental Science and Management not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (387, '050301', 'Carbon Sequestration Science');
INSERT INTO crams_forcode (id, code, description) VALUES (388, '050302', 'Land Capability and Soil Degradation');
INSERT INTO crams_forcode (id, code, description) VALUES (389, '050303', 'Soil Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (390, '050304', 'Soil Chemistry (excl. Carbon Sequestration Science)');
INSERT INTO crams_forcode (id, code, description) VALUES (391, '050305', 'Soil Physics');
INSERT INTO crams_forcode (id, code, description) VALUES (392, '050399', 'Soil Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (393, '059999', 'Environmental Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (394, '060101', 'Analytical Biochemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (395, '060102', 'Bioinformatics');
INSERT INTO crams_forcode (id, code, description) VALUES (396, '060103', 'Cell Development, Proliferation and Death');
INSERT INTO crams_forcode (id, code, description) VALUES (397, '060104', 'Cell Metabolism');
INSERT INTO crams_forcode (id, code, description) VALUES (398, '060105', 'Cell Neurochemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (399, '060106', 'Cellular Interactions (incl. Adhesion, Matrix, Cell Wall)');
INSERT INTO crams_forcode (id, code, description) VALUES (400, '060107', 'Enzymes');
INSERT INTO crams_forcode (id, code, description) VALUES (401, '060108', 'Protein Trafficking');
INSERT INTO crams_forcode (id, code, description) VALUES (402, '060109', 'Proteomics and Intermolecular Interactions (excl. Medical Proteomics)');
INSERT INTO crams_forcode (id, code, description) VALUES (403, '060110', 'Receptors and Membrane Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (404, '060111', 'Signal Transduction');
INSERT INTO crams_forcode (id, code, description) VALUES (405, '060112', 'Structural Biology (incl. Macromolecular Modelling)');
INSERT INTO crams_forcode (id, code, description) VALUES (406, '060113', 'Synthetic Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (407, '060114', 'Systems Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (408, '060199', 'Biochemistry and Cell Biology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (409, '060201', 'Behavioural Ecology');
INSERT INTO crams_forcode (id, code, description) VALUES (410, '060202', 'Community Ecology (excl. Invasive Species Ecology)');
INSERT INTO crams_forcode (id, code, description) VALUES (411, '060203', 'Ecological Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (412, '060204', 'Freshwater Ecology');
INSERT INTO crams_forcode (id, code, description) VALUES (413, '060205', 'Marine and Estuarine Ecology (incl. Marine Ichthyology)');
INSERT INTO crams_forcode (id, code, description) VALUES (414, '060206', 'Palaeoecology');
INSERT INTO crams_forcode (id, code, description) VALUES (415, '060207', 'Population Ecology');
INSERT INTO crams_forcode (id, code, description) VALUES (416, '060208', 'Terrestrial Ecology');
INSERT INTO crams_forcode (id, code, description) VALUES (417, '060299', 'Ecology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (418, '060301', 'Animal Systematics and Taxonomy');
INSERT INTO crams_forcode (id, code, description) VALUES (419, '060302', 'Biogeography and Phylogeography');
INSERT INTO crams_forcode (id, code, description) VALUES (420, '060303', 'Biological Adaptation');
INSERT INTO crams_forcode (id, code, description) VALUES (421, '060304', 'Ethology and Sociobiology');
INSERT INTO crams_forcode (id, code, description) VALUES (422, '060305', 'Evolution of Developmental Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (423, '060306', 'Evolutionary Impacts of Climate Change');
INSERT INTO crams_forcode (id, code, description) VALUES (424, '060307', 'Host-Parasite Interactions');
INSERT INTO crams_forcode (id, code, description) VALUES (425, '060308', 'Life Histories');
INSERT INTO crams_forcode (id, code, description) VALUES (426, '060309', 'Phylogeny and Comparative Analysis');
INSERT INTO crams_forcode (id, code, description) VALUES (427, '060310', 'Plant Systematics and Taxonomy');
INSERT INTO crams_forcode (id, code, description) VALUES (428, '060311', 'Speciation and Extinction');
INSERT INTO crams_forcode (id, code, description) VALUES (429, '060399', 'Evolutionary Biology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (430, '060401', 'Anthropological Genetics');
INSERT INTO crams_forcode (id, code, description) VALUES (431, '060402', 'Cell and Nuclear Division');
INSERT INTO crams_forcode (id, code, description) VALUES (432, '060403', 'Developmental Genetics (incl. Sex Determination)');
INSERT INTO crams_forcode (id, code, description) VALUES (433, '060404', 'Epigenetics (incl. Genome Methylation and Epigenomics)');
INSERT INTO crams_forcode (id, code, description) VALUES (434, '060405', 'Gene Expression (incl. Microarray and other genome-wide approaches)');
INSERT INTO crams_forcode (id, code, description) VALUES (435, '060406', 'Genetic Immunology');
INSERT INTO crams_forcode (id, code, description) VALUES (436, '060407', 'Genome Structure and Regulation');
INSERT INTO crams_forcode (id, code, description) VALUES (437, '060408', 'Genomics');
INSERT INTO crams_forcode (id, code, description) VALUES (438, '060409', 'Molecular Evolution');
INSERT INTO crams_forcode (id, code, description) VALUES (439, '060410', 'Neurogenetics');
INSERT INTO crams_forcode (id, code, description) VALUES (440, '060411', 'Population, Ecological and Evolutionary Genetics');
INSERT INTO crams_forcode (id, code, description) VALUES (441, '060412', 'Quantitative Genetics (incl. Disease and Trait Mapping Genetics)');
INSERT INTO crams_forcode (id, code, description) VALUES (442, '060499', 'Genetics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (443, '060501', 'Bacteriology');
INSERT INTO crams_forcode (id, code, description) VALUES (444, '060502', 'Infectious Agents');
INSERT INTO crams_forcode (id, code, description) VALUES (445, '060503', 'Microbial Genetics');
INSERT INTO crams_forcode (id, code, description) VALUES (446, '060504', 'Microbial Ecology');
INSERT INTO crams_forcode (id, code, description) VALUES (447, '060505', 'Mycology');
INSERT INTO crams_forcode (id, code, description) VALUES (448, '060506', 'Virology');
INSERT INTO crams_forcode (id, code, description) VALUES (449, '060599', 'Microbiology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (450, '060601', 'Animal Physiology - Biophysics');
INSERT INTO crams_forcode (id, code, description) VALUES (451, '060602', 'Animal Physiology - Cell');
INSERT INTO crams_forcode (id, code, description) VALUES (452, '060603', 'Animal Physiology - Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (453, '060604', 'Comparative Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (454, '060699', 'Physiology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (455, '060701', 'Phycology (incl. Marine Grasses)');
INSERT INTO crams_forcode (id, code, description) VALUES (456, '060702', 'Plant Cell and Molecular Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (457, '060703', 'Plant Developmental and Reproductive Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (458, '060704', 'Plant Pathology');
INSERT INTO crams_forcode (id, code, description) VALUES (459, '060705', 'Plant Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (460, '060799', 'Plant Biology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (461, '060801', 'Animal Behaviour');
INSERT INTO crams_forcode (id, code, description) VALUES (462, '060802', 'Animal Cell and Molecular Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (463, '060803', 'Animal Developmental and Reproductive Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (464, '060804', 'Animal Immunology');
INSERT INTO crams_forcode (id, code, description) VALUES (465, '060805', 'Animal Neurobiology');
INSERT INTO crams_forcode (id, code, description) VALUES (466, '060806', 'Animal Physiological Ecology');
INSERT INTO crams_forcode (id, code, description) VALUES (467, '060807', 'Animal Structure and Function');
INSERT INTO crams_forcode (id, code, description) VALUES (468, '060808', 'Invertebrate Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (469, '060809', 'Vertebrate Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (470, '060899', 'Zoology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (471, '069901', 'Forensic Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (472, '069902', 'Global Change Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (473, '069999', 'Biological Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (474, '070101', 'Agricultural Land Management');
INSERT INTO crams_forcode (id, code, description) VALUES (475, '070102', 'Agricultural Land Planning');
INSERT INTO crams_forcode (id, code, description) VALUES (476, '070103', 'Agricultural Production Systems Simulation');
INSERT INTO crams_forcode (id, code, description) VALUES (477, '070104', 'Agricultural Spatial Analysis and Modelling');
INSERT INTO crams_forcode (id, code, description) VALUES (478, '070105', 'Agricultural Systems Analysis and Modelling');
INSERT INTO crams_forcode (id, code, description) VALUES (479, '070106', 'Farm Management, Rural Management and Agribusiness');
INSERT INTO crams_forcode (id, code, description) VALUES (480, '070107', 'Farming Systems Research');
INSERT INTO crams_forcode (id, code, description) VALUES (481, '070108', 'Sustainable Agricultural Development');
INSERT INTO crams_forcode (id, code, description) VALUES (482, '070199', 'Agriculture, Land and Farm Management not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (483, '070201', 'Animal Breeding');
INSERT INTO crams_forcode (id, code, description) VALUES (484, '070202', 'Animal Growth and Development');
INSERT INTO crams_forcode (id, code, description) VALUES (485, '070203', 'Animal Management');
INSERT INTO crams_forcode (id, code, description) VALUES (486, '070204', 'Animal Nutrition');
INSERT INTO crams_forcode (id, code, description) VALUES (487, '070205', 'Animal Protection (Pests and Pathogens)');
INSERT INTO crams_forcode (id, code, description) VALUES (488, '070206', 'Animal Reproduction');
INSERT INTO crams_forcode (id, code, description) VALUES (489, '070207', 'Humane Animal Treatment');
INSERT INTO crams_forcode (id, code, description) VALUES (490, '070299', 'Animal Production not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (491, '070301', 'Agro-ecosystem Function and Prediction');
INSERT INTO crams_forcode (id, code, description) VALUES (492, '070302', 'Agronomy');
INSERT INTO crams_forcode (id, code, description) VALUES (493, '070303', 'Crop and Pasture Biochemistry and Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (494, '070304', 'Crop and Pasture Biomass and Bioproducts');
INSERT INTO crams_forcode (id, code, description) VALUES (495, '070305', 'Crop and Pasture Improvement (Selection and Breeding)');
INSERT INTO crams_forcode (id, code, description) VALUES (496, '070306', 'Crop and Pasture Nutrition');
INSERT INTO crams_forcode (id, code, description) VALUES (497, '070307', 'Crop and Pasture Post Harvest Technologies (incl. Transportation and Storage)');
INSERT INTO crams_forcode (id, code, description) VALUES (498, '070308', 'Crop and Pasture Protection (Pests, Diseases and Weeds)');
INSERT INTO crams_forcode (id, code, description) VALUES (499, '070399', 'Crop and Pasture Production not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (500, '070401', 'Aquaculture');
INSERT INTO crams_forcode (id, code, description) VALUES (501, '070402', 'Aquatic Ecosystem Studies and Stock Assessment');
INSERT INTO crams_forcode (id, code, description) VALUES (502, '070403', 'Fisheries Management');
INSERT INTO crams_forcode (id, code, description) VALUES (503, '070404', 'Fish Pests and Diseases');
INSERT INTO crams_forcode (id, code, description) VALUES (504, '070405', 'Fish Physiology and Genetics');
INSERT INTO crams_forcode (id, code, description) VALUES (505, '070406', 'Post-Harvest Fisheries Technologies (incl. Transportation)');
INSERT INTO crams_forcode (id, code, description) VALUES (506, '070499', 'Fisheries Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (507, '070501', 'Agroforestry');
INSERT INTO crams_forcode (id, code, description) VALUES (508, '070502', 'Forestry Biomass and Bioproducts');
INSERT INTO crams_forcode (id, code, description) VALUES (509, '070503', 'Forestry Fire Management');
INSERT INTO crams_forcode (id, code, description) VALUES (510, '070504', 'Forestry Management and Environment');
INSERT INTO crams_forcode (id, code, description) VALUES (511, '070505', 'Forestry Pests, Health and Diseases');
INSERT INTO crams_forcode (id, code, description) VALUES (512, '070506', 'Forestry Product Quality Assessment');
INSERT INTO crams_forcode (id, code, description) VALUES (513, '070507', 'Tree Improvement (Selection and Breeding)');
INSERT INTO crams_forcode (id, code, description) VALUES (514, '070508', 'Tree Nutrition and Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (515, '070509', 'Wood Fibre Processing');
INSERT INTO crams_forcode (id, code, description) VALUES (516, '070510', 'Wood Processing');
INSERT INTO crams_forcode (id, code, description) VALUES (517, '070599', 'Forestry Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (518, '070601', 'Horticultural Crop Growth and Development');
INSERT INTO crams_forcode (id, code, description) VALUES (519, '070602', 'Horticultural Crop Improvement (Selection and Breeding)');
INSERT INTO crams_forcode (id, code, description) VALUES (520, '070603', 'Horticultural Crop Protection (Pests, Diseases and Weeds)');
INSERT INTO crams_forcode (id, code, description) VALUES (521, '070604', 'Oenology and Viticulture');
INSERT INTO crams_forcode (id, code, description) VALUES (522, '070605', 'Post Harvest Horticultural Technologies (incl. Transportation and Storage)');
INSERT INTO crams_forcode (id, code, description) VALUES (523, '070699', 'Horticultural Production not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (524, '070701', 'Veterinary Anaesthesiology and Intensive Care');
INSERT INTO crams_forcode (id, code, description) VALUES (525, '070702', 'Veterinary Anatomy and Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (526, '070703', 'Veterinary Diagnosis and Diagnostics');
INSERT INTO crams_forcode (id, code, description) VALUES (527, '070704', 'Veterinary Epidemiology');
INSERT INTO crams_forcode (id, code, description) VALUES (528, '070705', 'Veterinary Immunology');
INSERT INTO crams_forcode (id, code, description) VALUES (529, '070706', 'Veterinary Medicine');
INSERT INTO crams_forcode (id, code, description) VALUES (530, '070707', 'Veterinary Microbiology (excl. Virology)');
INSERT INTO crams_forcode (id, code, description) VALUES (531, '070708', 'Veterinary Parasitology');
INSERT INTO crams_forcode (id, code, description) VALUES (532, '070709', 'Veterinary Pathology');
INSERT INTO crams_forcode (id, code, description) VALUES (533, '070710', 'Veterinary Pharmacology');
INSERT INTO crams_forcode (id, code, description) VALUES (534, '070711', 'Veterinary Surgery');
INSERT INTO crams_forcode (id, code, description) VALUES (535, '070712', 'Veterinary Virology');
INSERT INTO crams_forcode (id, code, description) VALUES (536, '070799', 'Veterinary Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (537, '079901', 'Agricultural Hydrology (Drainage, Flooding, Irrigation, Quality, etc.)');
INSERT INTO crams_forcode (id, code, description) VALUES (538, '079902', 'Fertilisers and Agrochemicals (incl. Application)');
INSERT INTO crams_forcode (id, code, description) VALUES (539, '079999', 'Agricultural and Veterinary Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (540, '080101', 'Adaptive Agents and Intelligent Robotics');
INSERT INTO crams_forcode (id, code, description) VALUES (541, '080102', 'Artificial Life');
INSERT INTO crams_forcode (id, code, description) VALUES (542, '080103', 'Computer Graphics');
INSERT INTO crams_forcode (id, code, description) VALUES (543, '080104', 'Computer Vision');
INSERT INTO crams_forcode (id, code, description) VALUES (544, '080105', 'Expert Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (545, '080106', 'Image Processing');
INSERT INTO crams_forcode (id, code, description) VALUES (546, '080107', 'Natural Language Processing');
INSERT INTO crams_forcode (id, code, description) VALUES (547, '080108', 'Neural, Evolutionary and Fuzzy Computation');
INSERT INTO crams_forcode (id, code, description) VALUES (548, '080109', 'Pattern Recognition and Data Mining');
INSERT INTO crams_forcode (id, code, description) VALUES (549, '080110', 'Simulation and Modelling');
INSERT INTO crams_forcode (id, code, description) VALUES (550, '080111', 'Virtual Reality and Related Simulation');
INSERT INTO crams_forcode (id, code, description) VALUES (551, '080199', 'Artificial Intelligence and Image Processing not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (552, '080201', 'Analysis of Algorithms and Complexity');
INSERT INTO crams_forcode (id, code, description) VALUES (553, '080202', 'Applied Discrete Mathematics');
INSERT INTO crams_forcode (id, code, description) VALUES (554, '080203', 'Computational Logic and Formal Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (555, '080204', 'Mathematical Software');
INSERT INTO crams_forcode (id, code, description) VALUES (556, '080205', 'Numerical Computation');
INSERT INTO crams_forcode (id, code, description) VALUES (557, '080299', 'Computation Theory and Mathematics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (558, '080301', 'Bioinformatics Software');
INSERT INTO crams_forcode (id, code, description) VALUES (559, '080302', 'Computer System Architecture');
INSERT INTO crams_forcode (id, code, description) VALUES (560, '080303', 'Computer System Security');
INSERT INTO crams_forcode (id, code, description) VALUES (561, '080304', 'Concurrent Programming');
INSERT INTO crams_forcode (id, code, description) VALUES (562, '080305', 'Multimedia Programming');
INSERT INTO crams_forcode (id, code, description) VALUES (563, '080306', 'Open Software');
INSERT INTO crams_forcode (id, code, description) VALUES (564, '080307', 'Operating Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (565, '080308', 'Programming Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (566, '080309', 'Software Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (567, '080399', 'Computer Software not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (568, '080401', 'Coding and Information Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (569, '080402', 'Data Encryption');
INSERT INTO crams_forcode (id, code, description) VALUES (570, '080403', 'Data Structures');
INSERT INTO crams_forcode (id, code, description) VALUES (571, '080404', 'Markup Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (572, '080499', 'Data Format not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (573, '080501', 'Distributed and Grid Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (574, '080502', 'Mobile Technologies');
INSERT INTO crams_forcode (id, code, description) VALUES (575, '080503', 'Networking and Communications');
INSERT INTO crams_forcode (id, code, description) VALUES (576, '080504', 'Ubiquitous Computing');
INSERT INTO crams_forcode (id, code, description) VALUES (577, '080505', 'Web Technologies (excl. Web Search)');
INSERT INTO crams_forcode (id, code, description) VALUES (578, '080599', 'Distributed Computing not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (579, '080601', 'Aboriginal and Torres Strait Islander Information and Knowledge Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (580, '080602', 'Computer-Human Interaction');
INSERT INTO crams_forcode (id, code, description) VALUES (581, '080603', 'Conceptual Modelling');
INSERT INTO crams_forcode (id, code, description) VALUES (582, '080604', 'Database Management');
INSERT INTO crams_forcode (id, code, description) VALUES (583, '080605', 'Decision Support and Group Support Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (584, '080606', 'Global Information Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (585, '080607', 'Information Engineering and Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (586, '080608', 'Information Systems Development Methodologies');
INSERT INTO crams_forcode (id, code, description) VALUES (587, '080609', 'Information Systems Management');
INSERT INTO crams_forcode (id, code, description) VALUES (588, '080610', 'Information Systems Organisation');
INSERT INTO crams_forcode (id, code, description) VALUES (589, '080611', 'Information Systems Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (590, '080612', 'Interorganisational Information Systems and Web Services');
INSERT INTO crams_forcode (id, code, description) VALUES (591, '080613', 'Maori Information and Knowledge Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (592, '080614', 'Pacific Peoples Information and Knowledge Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (593, '080699', 'Information Systems not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (594, '080701', 'Aboriginal and Torres Strait Islander Knowledge Management');
INSERT INTO crams_forcode (id, code, description) VALUES (595, '080702', 'Health Informatics');
INSERT INTO crams_forcode (id, code, description) VALUES (596, '080703', 'Human Information Behaviour');
INSERT INTO crams_forcode (id, code, description) VALUES (597, '080704', 'Information Retrieval and Web Search');
INSERT INTO crams_forcode (id, code, description) VALUES (598, '080705', 'Informetrics');
INSERT INTO crams_forcode (id, code, description) VALUES (599, '080706', 'Librarianship');
INSERT INTO crams_forcode (id, code, description) VALUES (600, '080707', 'Organisation of Information and Knowledge Resources');
INSERT INTO crams_forcode (id, code, description) VALUES (601, '080708', 'Records and Information Management (excl. Business Records and Information Management)');
INSERT INTO crams_forcode (id, code, description) VALUES (602, '080709', 'Social and Community Informatics');
INSERT INTO crams_forcode (id, code, description) VALUES (603, '080799', 'Library and Information Studies not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (604, '089999', 'Information and Computing Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (605, '090101', 'Aerodynamics (excl. Hypersonic Aerodynamics)');
INSERT INTO crams_forcode (id, code, description) VALUES (606, '090102', 'Aerospace Materials');
INSERT INTO crams_forcode (id, code, description) VALUES (607, '090103', 'Aerospace Structures');
INSERT INTO crams_forcode (id, code, description) VALUES (608, '090104', 'Aircraft Performance and Flight Control Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (609, '090105', 'Avionics');
INSERT INTO crams_forcode (id, code, description) VALUES (610, '090106', 'Flight Dynamics');
INSERT INTO crams_forcode (id, code, description) VALUES (611, '090107', 'Hypersonic Propulsion and Hypersonic Aerodynamics');
INSERT INTO crams_forcode (id, code, description) VALUES (612, '090108', 'Satellite, Space Vehicle and Missile Design and Testing');
INSERT INTO crams_forcode (id, code, description) VALUES (613, '090199', 'Aerospace Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (614, '090201', 'Automotive Combustion and Fuel Engineering (incl. Alternative/Renewable Fuels)');
INSERT INTO crams_forcode (id, code, description) VALUES (615, '090202', 'Automotive Engineering Materials');
INSERT INTO crams_forcode (id, code, description) VALUES (616, '090203', 'Automotive Mechatronics');
INSERT INTO crams_forcode (id, code, description) VALUES (617, '090204', 'Automotive Safety Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (618, '090205', 'Hybrid Vehicles and Powertrains');
INSERT INTO crams_forcode (id, code, description) VALUES (619, '090299', 'Automotive Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (620, '090301', 'Biomaterials');
INSERT INTO crams_forcode (id, code, description) VALUES (621, '090302', 'Biomechanical Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (622, '090303', 'Biomedical Instrumentation');
INSERT INTO crams_forcode (id, code, description) VALUES (623, '090304', 'Medical Devices');
INSERT INTO crams_forcode (id, code, description) VALUES (624, '090305', 'Rehabilitation Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (625, '090399', 'Biomedical Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (626, '090401', 'Carbon Capture Engineering (excl. Sequestration)');
INSERT INTO crams_forcode (id, code, description) VALUES (627, '090402', 'Catalytic Process Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (628, '090403', 'Chemical Engineering Design');
INSERT INTO crams_forcode (id, code, description) VALUES (629, '090405', 'Non-automotive Combustion and Fuel Engineering (incl. Alternative/Renewable Fuels)');
INSERT INTO crams_forcode (id, code, description) VALUES (630, '090404', 'Membrane and Separation Technologies');
INSERT INTO crams_forcode (id, code, description) VALUES (631, '090406', 'Powder and Particle Technology');
INSERT INTO crams_forcode (id, code, description) VALUES (632, '090407', 'Process Control and Simulation');
INSERT INTO crams_forcode (id, code, description) VALUES (633, '090408', 'Rheology');
INSERT INTO crams_forcode (id, code, description) VALUES (634, '090409', 'Wastewater Treatment Processes');
INSERT INTO crams_forcode (id, code, description) VALUES (635, '090410', 'Water Treatment Processes');
INSERT INTO crams_forcode (id, code, description) VALUES (636, '090499', 'Chemical Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (637, '090501', 'Civil Geotechnical Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (638, '090502', 'Construction Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (639, '090503', 'Construction Materials');
INSERT INTO crams_forcode (id, code, description) VALUES (640, '090504', 'Earthquake Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (641, '090505', 'Infrastructure Engineering and Asset Management');
INSERT INTO crams_forcode (id, code, description) VALUES (642, '090506', 'Structural Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (643, '090507', 'Transport Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (644, '090508', 'Water Quality Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (645, '090509', 'Water Resources Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (646, '090599', 'Civil Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (647, '090601', 'Circuits and Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (648, '090602', 'Control Systems, Robotics and Automation');
INSERT INTO crams_forcode (id, code, description) VALUES (649, '090603', 'Industrial Electronics');
INSERT INTO crams_forcode (id, code, description) VALUES (650, '090604', 'Microelectronics and Integrated Circuits');
INSERT INTO crams_forcode (id, code, description) VALUES (651, '090605', 'Photodetectors, Optical Sensors and Solar Cells');
INSERT INTO crams_forcode (id, code, description) VALUES (652, '090606', 'Photonics and Electro-Optical Engineering (excl. Communications)');
INSERT INTO crams_forcode (id, code, description) VALUES (653, '090607', 'Power and Energy Systems Engineering (excl. Renewable Power)');
INSERT INTO crams_forcode (id, code, description) VALUES (654, '090608', 'Renewable Power and Energy Systems Engineering (excl. Solar Cells)');
INSERT INTO crams_forcode (id, code, description) VALUES (655, '090609', 'Signal Processing');
INSERT INTO crams_forcode (id, code, description) VALUES (656, '090699', 'Electrical and Electronic Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (657, '090701', 'Environmental Engineering Design');
INSERT INTO crams_forcode (id, code, description) VALUES (658, '090702', 'Environmental Engineering Modelling');
INSERT INTO crams_forcode (id, code, description) VALUES (659, '090703', 'Environmental Technologies');
INSERT INTO crams_forcode (id, code, description) VALUES (660, '090799', 'Environmental Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (661, '090801', 'Food Chemistry and Molecular Gastronomy (excl. Wine)');
INSERT INTO crams_forcode (id, code, description) VALUES (662, '090802', 'Food Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (663, '090803', 'Food Nutritional Balance');
INSERT INTO crams_forcode (id, code, description) VALUES (664, '090804', 'Food Packaging, Preservation and Safety');
INSERT INTO crams_forcode (id, code, description) VALUES (665, '090805', 'Food Processing');
INSERT INTO crams_forcode (id, code, description) VALUES (666, '090806', 'Wine Chemistry and Wine Sensory Science');
INSERT INTO crams_forcode (id, code, description) VALUES (667, '090899', 'Food Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (668, '090901', 'Cartography');
INSERT INTO crams_forcode (id, code, description) VALUES (669, '090902', 'Geodesy');
INSERT INTO crams_forcode (id, code, description) VALUES (670, '090903', 'Geospatial Information Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (671, '090904', 'Navigation and Position Fixing');
INSERT INTO crams_forcode (id, code, description) VALUES (672, '090905', 'Photogrammetry and Remote Sensing');
INSERT INTO crams_forcode (id, code, description) VALUES (673, '090906', 'Surveying (incl. Hydrographic Surveying)');
INSERT INTO crams_forcode (id, code, description) VALUES (674, '090999', 'Geomatic Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (675, '091001', 'CAD/CAM Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (676, '091002', 'Flexible Manufacturing Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (677, '091003', 'Machine Tools');
INSERT INTO crams_forcode (id, code, description) VALUES (678, '091004', 'Machining');
INSERT INTO crams_forcode (id, code, description) VALUES (679, '091005', 'Manufacturing Management');
INSERT INTO crams_forcode (id, code, description) VALUES (680, '091006', 'Manufacturing Processes and Technologies (excl. Textiles)');
INSERT INTO crams_forcode (id, code, description) VALUES (681, '091007', 'Manufacturing Robotics and Mechatronics (excl. Automotive Mechatronics)');
INSERT INTO crams_forcode (id, code, description) VALUES (682, '091008', 'Manufacturing Safety and Quality');
INSERT INTO crams_forcode (id, code, description) VALUES (683, '091009', 'Microtechnology');
INSERT INTO crams_forcode (id, code, description) VALUES (684, '091010', 'Packaging, Storage and Transportation (excl. Food and Agricultural Products)');
INSERT INTO crams_forcode (id, code, description) VALUES (685, '091011', 'Precision Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (686, '091012', 'Textile Technology');
INSERT INTO crams_forcode (id, code, description) VALUES (687, '091099', 'Manufacturing Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (688, '091101', 'Marine Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (689, '091102', 'Naval Architecture');
INSERT INTO crams_forcode (id, code, description) VALUES (690, '091103', 'Ocean Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (691, '091104', 'Ship and Platform Hydrodynamics');
INSERT INTO crams_forcode (id, code, description) VALUES (692, '091105', 'Ship and Platform Structures');
INSERT INTO crams_forcode (id, code, description) VALUES (693, '091106', 'Special Vehicles');
INSERT INTO crams_forcode (id, code, description) VALUES (694, '091199', 'Maritime Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (695, '091201', 'Ceramics');
INSERT INTO crams_forcode (id, code, description) VALUES (696, '091202', 'Composite and Hybrid Materials');
INSERT INTO crams_forcode (id, code, description) VALUES (697, '091203', 'Compound Semiconductors');
INSERT INTO crams_forcode (id, code, description) VALUES (698, '091204', 'Elemental Semiconductors');
INSERT INTO crams_forcode (id, code, description) VALUES (699, '091205', 'Functional Materials');
INSERT INTO crams_forcode (id, code, description) VALUES (700, '091206', 'Glass');
INSERT INTO crams_forcode (id, code, description) VALUES (701, '091207', 'Metals and Alloy Materials');
INSERT INTO crams_forcode (id, code, description) VALUES (702, '091208', 'Organic Semiconductors');
INSERT INTO crams_forcode (id, code, description) VALUES (703, '091209', 'Polymers and Plastics');
INSERT INTO crams_forcode (id, code, description) VALUES (704, '091210', 'Timber, Pulp and Paper');
INSERT INTO crams_forcode (id, code, description) VALUES (705, '091299', 'Materials Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (706, '091301', 'Acoustics and Noise Control (excl. Architectural Acoustics)');
INSERT INTO crams_forcode (id, code, description) VALUES (707, '091302', 'Automation and Control Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (708, '091303', 'Autonomous Vehicles');
INSERT INTO crams_forcode (id, code, description) VALUES (709, '091304', 'Dynamics, Vibration and Vibration Control');
INSERT INTO crams_forcode (id, code, description) VALUES (710, '091305', 'Energy Generation, Conversion and Storage Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (711, '091306', 'Microelectromechanical Systems (MEMS)');
INSERT INTO crams_forcode (id, code, description) VALUES (712, '091307', 'Numerical Modelling and Mechanical Characterisation');
INSERT INTO crams_forcode (id, code, description) VALUES (713, '091308', 'Solid Mechanics');
INSERT INTO crams_forcode (id, code, description) VALUES (714, '091309', 'Tribology');
INSERT INTO crams_forcode (id, code, description) VALUES (715, '091399', 'Mechanical Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (716, '091401', 'Electrometallurgy');
INSERT INTO crams_forcode (id, code, description) VALUES (717, '091402', 'Geomechanics and Resources Geotechnical Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (718, '091403', 'Hydrometallurgy');
INSERT INTO crams_forcode (id, code, description) VALUES (719, '091404', 'Mineral Processing/Beneficiation');
INSERT INTO crams_forcode (id, code, description) VALUES (720, '091405', 'Mining Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (721, '091406', 'Petroleum and Reservoir Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (722, '091407', 'Pyrometallurgy');
INSERT INTO crams_forcode (id, code, description) VALUES (723, '091499', 'Resources Engineering and Extractive Metallurgy not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (724, '091501', 'Computational Fluid Dynamics');
INSERT INTO crams_forcode (id, code, description) VALUES (725, '091502', 'Computational Heat Transfer');
INSERT INTO crams_forcode (id, code, description) VALUES (726, '091503', 'Engineering Practice');
INSERT INTO crams_forcode (id, code, description) VALUES (727, '091504', 'Fluidisation and Fluid Mechanics');
INSERT INTO crams_forcode (id, code, description) VALUES (728, '091505', 'Heat and Mass Transfer Operations');
INSERT INTO crams_forcode (id, code, description) VALUES (729, '091506', 'Nuclear Engineering (incl. Fuel Enrichment and Waste Processing and Storage)');
INSERT INTO crams_forcode (id, code, description) VALUES (730, '091507', 'Risk Engineering (excl. Earthquake Engineering)');
INSERT INTO crams_forcode (id, code, description) VALUES (731, '091508', 'Turbulent Flows');
INSERT INTO crams_forcode (id, code, description) VALUES (732, '091599', 'Interdisciplinary Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (733, '099901', 'Agricultural Engineering');
INSERT INTO crams_forcode (id, code, description) VALUES (734, '099902', 'Engineering Instrumentation');
INSERT INTO crams_forcode (id, code, description) VALUES (735, '099999', 'Engineering not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (736, '100101', 'Agricultural Biotechnology Diagnostics (incl. Biosensors)');
INSERT INTO crams_forcode (id, code, description) VALUES (737, '100102', 'Agricultural Marine Biotechnology');
INSERT INTO crams_forcode (id, code, description) VALUES (738, '100103', 'Agricultural Molecular Engineering of Nucleic Acids and Proteins');
INSERT INTO crams_forcode (id, code, description) VALUES (739, '100104', 'Genetically Modified Animals');
INSERT INTO crams_forcode (id, code, description) VALUES (740, '100105', 'Genetically Modified Field Crops and Pasture');
INSERT INTO crams_forcode (id, code, description) VALUES (741, '100106', 'Genetically Modified Horticulture Plants');
INSERT INTO crams_forcode (id, code, description) VALUES (742, '100107', 'Genetically Modified Trees');
INSERT INTO crams_forcode (id, code, description) VALUES (743, '100108', 'Livestock cloning');
INSERT INTO crams_forcode (id, code, description) VALUES (744, '100109', 'Transgenesis');
INSERT INTO crams_forcode (id, code, description) VALUES (745, '100199', 'Agricultural Biotechnology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (746, '100201', 'Biodiscovery');
INSERT INTO crams_forcode (id, code, description) VALUES (747, '100202', 'Biological Control');
INSERT INTO crams_forcode (id, code, description) VALUES (748, '100203', 'Bioremediation');
INSERT INTO crams_forcode (id, code, description) VALUES (1067, '150305', 'Human Resources Management');
INSERT INTO crams_forcode (id, code, description) VALUES (749, '100204', 'Environmental Biotechnology Diagnostics (incl. Biosensors)');
INSERT INTO crams_forcode (id, code, description) VALUES (750, '100205', 'Environmental Marine Biotechnology');
INSERT INTO crams_forcode (id, code, description) VALUES (751, '100206', 'Environmental Molecular Engineering of Nucleic Acids and Proteins');
INSERT INTO crams_forcode (id, code, description) VALUES (752, '100299', 'Environmental Biotechnology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (753, '100301', 'Biocatalysis and Enzyme Technology');
INSERT INTO crams_forcode (id, code, description) VALUES (754, '100302', 'Bioprocessing, Bioproduction and Bioproducts');
INSERT INTO crams_forcode (id, code, description) VALUES (755, '100303', 'Fermentation');
INSERT INTO crams_forcode (id, code, description) VALUES (756, '100304', 'Industrial Biotechnology Diagnostics (incl. Biosensors)');
INSERT INTO crams_forcode (id, code, description) VALUES (757, '100305', 'Industrial Microbiology (incl. Biofeedstocks)');
INSERT INTO crams_forcode (id, code, description) VALUES (758, '100306', 'Industrial Molecular Engineering of Nucleic Acids and Proteins');
INSERT INTO crams_forcode (id, code, description) VALUES (759, '100399', 'Industrial Biotechnology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (760, '100401', 'Gene and Molecular Therapy');
INSERT INTO crams_forcode (id, code, description) VALUES (761, '100402', 'Medical Biotechnology Diagnostics (incl. Biosensors)');
INSERT INTO crams_forcode (id, code, description) VALUES (762, '100403', 'Medical Molecular Engineering of Nucleic Acids and Proteins');
INSERT INTO crams_forcode (id, code, description) VALUES (763, '100404', 'Regenerative Medicine (incl. Stem Cells and Tissue Engineering)');
INSERT INTO crams_forcode (id, code, description) VALUES (764, '100499', 'Medical Biotechnology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (765, '100501', 'Antennas and Propagation');
INSERT INTO crams_forcode (id, code, description) VALUES (766, '100502', 'Broadband and Modem Technology');
INSERT INTO crams_forcode (id, code, description) VALUES (767, '100503', 'Computer Communications Networks');
INSERT INTO crams_forcode (id, code, description) VALUES (768, '100504', 'Data Communications');
INSERT INTO crams_forcode (id, code, description) VALUES (769, '100505', 'Microwave and Millimetrewave Theory and Technology');
INSERT INTO crams_forcode (id, code, description) VALUES (770, '100506', 'Optical Fibre Communications');
INSERT INTO crams_forcode (id, code, description) VALUES (771, '100507', 'Optical Networks and Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (772, '100508', 'Satellite Communications');
INSERT INTO crams_forcode (id, code, description) VALUES (773, '100509', 'Video Communications');
INSERT INTO crams_forcode (id, code, description) VALUES (774, '100510', 'Wireless Communications');
INSERT INTO crams_forcode (id, code, description) VALUES (775, '100599', 'Communications Technologies not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (776, '100601', 'Arithmetic and Logic Structures');
INSERT INTO crams_forcode (id, code, description) VALUES (777, '100602', 'Input, Output and Data Devices');
INSERT INTO crams_forcode (id, code, description) VALUES (778, '100603', 'Logic Design');
INSERT INTO crams_forcode (id, code, description) VALUES (779, '100604', 'Memory Structures');
INSERT INTO crams_forcode (id, code, description) VALUES (780, '100605', 'Performance Evaluation; Testing and Simulation of Reliability');
INSERT INTO crams_forcode (id, code, description) VALUES (781, '100606', 'Processor Architectures');
INSERT INTO crams_forcode (id, code, description) VALUES (782, '100699', 'Computer Hardware not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (783, '100701', 'Environmental Nanotechnology');
INSERT INTO crams_forcode (id, code, description) VALUES (784, '100702', 'Molecular and Organic Electronics');
INSERT INTO crams_forcode (id, code, description) VALUES (785, '100703', 'Nanobiotechnology');
INSERT INTO crams_forcode (id, code, description) VALUES (786, '100704', 'Nanoelectromechanical Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (787, '100705', 'Nanoelectronics');
INSERT INTO crams_forcode (id, code, description) VALUES (788, '100706', 'Nanofabrication, Growth and Self Assembly');
INSERT INTO crams_forcode (id, code, description) VALUES (789, '100707', 'Nanomanufacturing');
INSERT INTO crams_forcode (id, code, description) VALUES (790, '100708', 'Nanomaterials');
INSERT INTO crams_forcode (id, code, description) VALUES (791, '100709', 'Nanomedicine');
INSERT INTO crams_forcode (id, code, description) VALUES (792, '100710', 'Nanometrology');
INSERT INTO crams_forcode (id, code, description) VALUES (793, '100711', 'Nanophotonics');
INSERT INTO crams_forcode (id, code, description) VALUES (794, '100712', 'Nanoscale Characterisation');
INSERT INTO crams_forcode (id, code, description) VALUES (795, '100713', 'Nanotoxicology, Health and Safety');
INSERT INTO crams_forcode (id, code, description) VALUES (796, '100799', 'Nanotechnology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (797, '109999', 'Technology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (798, '110101', 'Medical Biochemistry: Amino Acids and Metabolites');
INSERT INTO crams_forcode (id, code, description) VALUES (799, '110102', 'Medical Biochemistry: Carbohydrates');
INSERT INTO crams_forcode (id, code, description) VALUES (800, '110103', 'Medical Biochemistry: Inorganic Elements and Compounds');
INSERT INTO crams_forcode (id, code, description) VALUES (801, '110104', 'Medical Biochemistry: Lipids');
INSERT INTO crams_forcode (id, code, description) VALUES (802, '110105', 'Medical Biochemistry: Nucleic Acids');
INSERT INTO crams_forcode (id, code, description) VALUES (803, '110106', 'Medical Biochemistry: Proteins and Peptides (incl. Medical Proteomics)');
INSERT INTO crams_forcode (id, code, description) VALUES (804, '110107', 'Metabolic Medicine');
INSERT INTO crams_forcode (id, code, description) VALUES (805, '110199', 'Medical Biochemistry and Metabolomics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (806, '110201', 'Cardiology (incl. Cardiovascular Diseases)');
INSERT INTO crams_forcode (id, code, description) VALUES (807, '110202', 'Haematology');
INSERT INTO crams_forcode (id, code, description) VALUES (808, '110203', 'Respiratory Diseases');
INSERT INTO crams_forcode (id, code, description) VALUES (809, '110299', 'Cardiorespiratory Medicine and Haematology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (810, '110301', 'Anaesthesiology');
INSERT INTO crams_forcode (id, code, description) VALUES (811, '110302', 'Clinical Chemistry (diagnostics)');
INSERT INTO crams_forcode (id, code, description) VALUES (812, '110303', 'Clinical Microbiology');
INSERT INTO crams_forcode (id, code, description) VALUES (813, '110304', 'Dermatology');
INSERT INTO crams_forcode (id, code, description) VALUES (814, '110305', 'Emergency Medicine');
INSERT INTO crams_forcode (id, code, description) VALUES (815, '110306', 'Endocrinology');
INSERT INTO crams_forcode (id, code, description) VALUES (816, '110307', 'Gastroenterology and Hepatology');
INSERT INTO crams_forcode (id, code, description) VALUES (817, '110308', 'Geriatrics and Gerontology');
INSERT INTO crams_forcode (id, code, description) VALUES (818, '110309', 'Infectious Diseases');
INSERT INTO crams_forcode (id, code, description) VALUES (819, '110310', 'Intensive Care');
INSERT INTO crams_forcode (id, code, description) VALUES (820, '110311', 'Medical Genetics (excl. Cancer Genetics)');
INSERT INTO crams_forcode (id, code, description) VALUES (821, '110312', 'Nephrology and Urology');
INSERT INTO crams_forcode (id, code, description) VALUES (822, '110313', 'Nuclear Medicine');
INSERT INTO crams_forcode (id, code, description) VALUES (823, '110314', 'Orthopaedics');
INSERT INTO crams_forcode (id, code, description) VALUES (824, '110315', 'Otorhinolaryngology');
INSERT INTO crams_forcode (id, code, description) VALUES (825, '110316', 'Pathology (excl. Oral Pathology)');
INSERT INTO crams_forcode (id, code, description) VALUES (826, '110317', 'Physiotherapy');
INSERT INTO crams_forcode (id, code, description) VALUES (827, '110318', 'Podiatry');
INSERT INTO crams_forcode (id, code, description) VALUES (828, '110319', 'Psychiatry (incl. Psychotherapy)');
INSERT INTO crams_forcode (id, code, description) VALUES (829, '110320', 'Radiology and Organ Imaging');
INSERT INTO crams_forcode (id, code, description) VALUES (830, '110321', 'Rehabilitation and Therapy (excl. Physiotherapy)');
INSERT INTO crams_forcode (id, code, description) VALUES (831, '110322', 'Rheumatology and Arthritis');
INSERT INTO crams_forcode (id, code, description) VALUES (832, '110323', 'Surgery');
INSERT INTO crams_forcode (id, code, description) VALUES (833, '110324', 'Venereology');
INSERT INTO crams_forcode (id, code, description) VALUES (834, '110399', 'Clinical Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (835, '110401', 'Chiropractic');
INSERT INTO crams_forcode (id, code, description) VALUES (836, '110402', 'Naturopathy');
INSERT INTO crams_forcode (id, code, description) VALUES (837, '110403', 'Traditional Aboriginal and Torres Strait Islander Medicine and Treatments');
INSERT INTO crams_forcode (id, code, description) VALUES (838, '110404', 'Traditional Chinese Medicine and Treatments');
INSERT INTO crams_forcode (id, code, description) VALUES (839, '110405', 'Traditional Maori Medicine and Treatments');
INSERT INTO crams_forcode (id, code, description) VALUES (840, '110499', 'Complementary and Alternative Medicine not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (841, '110501', 'Dental Materials and Equipment');
INSERT INTO crams_forcode (id, code, description) VALUES (842, '110502', 'Dental Therapeutics, Pharmacology and Toxicology');
INSERT INTO crams_forcode (id, code, description) VALUES (843, '110503', 'Endodontics');
INSERT INTO crams_forcode (id, code, description) VALUES (844, '110504', 'Oral and Maxillofacial Surgery');
INSERT INTO crams_forcode (id, code, description) VALUES (845, '110505', 'Oral Medicine and Pathology');
INSERT INTO crams_forcode (id, code, description) VALUES (846, '110506', 'Orthodontics and Dentofacial Orthopaedics');
INSERT INTO crams_forcode (id, code, description) VALUES (847, '110507', 'Paedodontics');
INSERT INTO crams_forcode (id, code, description) VALUES (848, '110508', 'Periodontics');
INSERT INTO crams_forcode (id, code, description) VALUES (849, '110509', 'Special Needs Dentistry');
INSERT INTO crams_forcode (id, code, description) VALUES (850, '110599', 'Dentistry not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (851, '110601', 'Biomechanics');
INSERT INTO crams_forcode (id, code, description) VALUES (852, '110602', 'Exercise Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (853, '110603', 'Motor Control');
INSERT INTO crams_forcode (id, code, description) VALUES (854, '110604', 'Sports Medicine');
INSERT INTO crams_forcode (id, code, description) VALUES (855, '110699', 'Human Movement and Sports Science not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (856, '110701', 'Allergy');
INSERT INTO crams_forcode (id, code, description) VALUES (1068, '150306', 'Industrial Relations');
INSERT INTO crams_forcode (id, code, description) VALUES (857, '110702', 'Applied Immunology (incl. Antibody Engineering, Xenotransplantation and T-cell Therapies)');
INSERT INTO crams_forcode (id, code, description) VALUES (858, '110703', 'Autoimmunity');
INSERT INTO crams_forcode (id, code, description) VALUES (859, '110704', 'Cellular Immunology');
INSERT INTO crams_forcode (id, code, description) VALUES (860, '110705', 'Humoural Immunology and Immunochemistry');
INSERT INTO crams_forcode (id, code, description) VALUES (861, '110706', 'Immunogenetics (incl. Genetic Immunology)');
INSERT INTO crams_forcode (id, code, description) VALUES (862, '110707', 'Innate Immunity');
INSERT INTO crams_forcode (id, code, description) VALUES (863, '110708', 'Transplantation Immunology');
INSERT INTO crams_forcode (id, code, description) VALUES (864, '110709', 'Tumour Immunology');
INSERT INTO crams_forcode (id, code, description) VALUES (865, '110799', 'Immunology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (866, '110801', 'Medical Bacteriology');
INSERT INTO crams_forcode (id, code, description) VALUES (867, '110802', 'Medical Infection Agents (incl. Prions)');
INSERT INTO crams_forcode (id, code, description) VALUES (868, '110803', 'Medical Parasitology');
INSERT INTO crams_forcode (id, code, description) VALUES (869, '110804', 'Medical Virology');
INSERT INTO crams_forcode (id, code, description) VALUES (870, '110899', 'Medical Microbiology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (871, '110901', 'Autonomic Nervous System');
INSERT INTO crams_forcode (id, code, description) VALUES (872, '110902', 'Cellular Nervous System');
INSERT INTO crams_forcode (id, code, description) VALUES (873, '110903', 'Central Nervous System');
INSERT INTO crams_forcode (id, code, description) VALUES (874, '110904', 'Neurology and Neuromuscular Diseases');
INSERT INTO crams_forcode (id, code, description) VALUES (875, '110905', 'Peripheral Nervous System');
INSERT INTO crams_forcode (id, code, description) VALUES (876, '110906', 'Sensory Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (877, '110999', 'Neurosciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (878, '111001', 'Aged Care Nursing');
INSERT INTO crams_forcode (id, code, description) VALUES (879, '111002', 'Clinical Nursing: Primary (Preventative)');
INSERT INTO crams_forcode (id, code, description) VALUES (880, '111003', 'Clinical Nursing: Secondary (Acute Care)');
INSERT INTO crams_forcode (id, code, description) VALUES (881, '111004', 'Clinical Nursing: Tertiary (Rehabilitative)');
INSERT INTO crams_forcode (id, code, description) VALUES (882, '111005', 'Mental Health Nursing');
INSERT INTO crams_forcode (id, code, description) VALUES (883, '111006', 'Midwifery');
INSERT INTO crams_forcode (id, code, description) VALUES (884, '111099', 'Nursing not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (885, '111101', 'Clinical and Sports Nutrition');
INSERT INTO crams_forcode (id, code, description) VALUES (886, '111102', 'Dietetics and Nutrigenomics');
INSERT INTO crams_forcode (id, code, description) VALUES (887, '111103', 'Nutritional Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (888, '111104', 'Public Nutrition Intervention');
INSERT INTO crams_forcode (id, code, description) VALUES (889, '111199', 'Nutrition and Dietetics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (890, '111201', 'Cancer Cell Biology');
INSERT INTO crams_forcode (id, code, description) VALUES (891, '111202', 'Cancer Diagnosis');
INSERT INTO crams_forcode (id, code, description) VALUES (892, '111203', 'Cancer Genetics');
INSERT INTO crams_forcode (id, code, description) VALUES (893, '111204', 'Cancer Therapy (excl. Chemotherapy and Radiation Therapy)');
INSERT INTO crams_forcode (id, code, description) VALUES (894, '111205', 'Chemotherapy');
INSERT INTO crams_forcode (id, code, description) VALUES (895, '111206', 'Haematological Tumours');
INSERT INTO crams_forcode (id, code, description) VALUES (896, '111207', 'Molecular Targets');
INSERT INTO crams_forcode (id, code, description) VALUES (897, '111208', 'Radiation Therapy');
INSERT INTO crams_forcode (id, code, description) VALUES (898, '111209', 'Solid Tumours');
INSERT INTO crams_forcode (id, code, description) VALUES (899, '111299', 'Oncology and Carcinogenesis not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (900, '111301', 'Ophthalmology');
INSERT INTO crams_forcode (id, code, description) VALUES (901, '111302', 'Optical Technology');
INSERT INTO crams_forcode (id, code, description) VALUES (902, '111303', 'Vision Science');
INSERT INTO crams_forcode (id, code, description) VALUES (903, '111399', 'Ophthalmology and Optometry not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (904, '111401', 'Foetal Development and Medicine');
INSERT INTO crams_forcode (id, code, description) VALUES (905, '111402', 'Obstetrics and Gynaecology');
INSERT INTO crams_forcode (id, code, description) VALUES (906, '111403', 'Paediatrics');
INSERT INTO crams_forcode (id, code, description) VALUES (907, '111404', 'Reproduction');
INSERT INTO crams_forcode (id, code, description) VALUES (908, '111499', 'Paediatrics and Reproductive Medicine not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (909, '111501', 'Basic Pharmacology');
INSERT INTO crams_forcode (id, code, description) VALUES (910, '111502', 'Clinical Pharmacology and Therapeutics');
INSERT INTO crams_forcode (id, code, description) VALUES (911, '111503', 'Clinical Pharmacy and Pharmacy Practice');
INSERT INTO crams_forcode (id, code, description) VALUES (912, '111504', 'Pharmaceutical Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (913, '111505', 'Pharmacogenomics');
INSERT INTO crams_forcode (id, code, description) VALUES (914, '111506', 'Toxicology (incl. Clinical Toxicology)');
INSERT INTO crams_forcode (id, code, description) VALUES (915, '111599', 'Pharmacology and Pharmaceutical Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (916, '111601', 'Cell Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (917, '111602', 'Human Biophysics');
INSERT INTO crams_forcode (id, code, description) VALUES (918, '111603', 'Systems Physiology');
INSERT INTO crams_forcode (id, code, description) VALUES (919, '111699', 'Medical Physiology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (920, '111701', 'Aboriginal and Torres Strait Islander Health');
INSERT INTO crams_forcode (id, code, description) VALUES (921, '111702', 'Aged Health Care');
INSERT INTO crams_forcode (id, code, description) VALUES (922, '111703', 'Care for Disabled');
INSERT INTO crams_forcode (id, code, description) VALUES (923, '111704', 'Community Child Health');
INSERT INTO crams_forcode (id, code, description) VALUES (924, '111705', 'Environmental and Occupational Health and Safety');
INSERT INTO crams_forcode (id, code, description) VALUES (925, '111706', 'Epidemiology');
INSERT INTO crams_forcode (id, code, description) VALUES (926, '111707', 'Family Care');
INSERT INTO crams_forcode (id, code, description) VALUES (927, '111708', 'Health and Community Services');
INSERT INTO crams_forcode (id, code, description) VALUES (928, '111709', 'Health Care Administration');
INSERT INTO crams_forcode (id, code, description) VALUES (929, '111710', 'Health Counselling');
INSERT INTO crams_forcode (id, code, description) VALUES (930, '111711', 'Health Information Systems (incl. Surveillance)');
INSERT INTO crams_forcode (id, code, description) VALUES (931, '111712', 'Health Promotion');
INSERT INTO crams_forcode (id, code, description) VALUES (932, '111713', 'Mauri Health');
INSERT INTO crams_forcode (id, code, description) VALUES (933, '111714', 'Mental Health');
INSERT INTO crams_forcode (id, code, description) VALUES (934, '111715', 'Pacific Peoples Health');
INSERT INTO crams_forcode (id, code, description) VALUES (935, '111716', 'Preventive Medicine');
INSERT INTO crams_forcode (id, code, description) VALUES (936, '111717', 'Primary Health Care');
INSERT INTO crams_forcode (id, code, description) VALUES (937, '111718', 'Residential Client Care');
INSERT INTO crams_forcode (id, code, description) VALUES (938, '111799', 'Public Health and Health Services not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (939, '119999', 'Medical and Health Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (940, '120101', 'Architectural Design');
INSERT INTO crams_forcode (id, code, description) VALUES (941, '120102', 'Architectural Heritage and Conservation');
INSERT INTO crams_forcode (id, code, description) VALUES (942, '120103', 'Architectural History and Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (943, '120104', 'Architectural Science and Technology (incl. Acoustics, Lighting, Structure and Ecologically Sustainable Design)');
INSERT INTO crams_forcode (id, code, description) VALUES (944, '120105', 'Architecture Management');
INSERT INTO crams_forcode (id, code, description) VALUES (945, '120106', 'Interior Design');
INSERT INTO crams_forcode (id, code, description) VALUES (946, '120107', 'Landscape Architecture');
INSERT INTO crams_forcode (id, code, description) VALUES (947, '120199', 'Architecture not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (948, '120201', 'Building Construction Management and Project Planning');
INSERT INTO crams_forcode (id, code, description) VALUES (949, '120202', 'Building Science and Techniques');
INSERT INTO crams_forcode (id, code, description) VALUES (950, '120203', 'Quantity Surveying');
INSERT INTO crams_forcode (id, code, description) VALUES (951, '120299', 'Building not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (952, '120301', 'Design History and Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (953, '120302', 'Design Innovation');
INSERT INTO crams_forcode (id, code, description) VALUES (954, '120303', 'Design Management and Studio and Professional Practice');
INSERT INTO crams_forcode (id, code, description) VALUES (955, '120304', 'Digital and Interaction Design');
INSERT INTO crams_forcode (id, code, description) VALUES (956, '120305', 'Industrial Design');
INSERT INTO crams_forcode (id, code, description) VALUES (957, '120306', 'Textile and Fashion Design');
INSERT INTO crams_forcode (id, code, description) VALUES (958, '120307', 'Visual Communication Design (incl. Graphic Design)');
INSERT INTO crams_forcode (id, code, description) VALUES (959, '120399', 'Design Practice and Management not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (960, '120401', 'Engineering Design Empirical Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (961, '120402', 'Engineering Design Knowledge');
INSERT INTO crams_forcode (id, code, description) VALUES (962, '120403', 'Engineering Design Methods');
INSERT INTO crams_forcode (id, code, description) VALUES (963, '120404', 'Engineering Systems Design');
INSERT INTO crams_forcode (id, code, description) VALUES (964, '120405', 'Models of Engineering Design');
INSERT INTO crams_forcode (id, code, description) VALUES (965, '120499', 'Engineering Design not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (966, '120501', 'Community Planning');
INSERT INTO crams_forcode (id, code, description) VALUES (967, '120502', 'History and Theory of the Built Environment (excl. Architecture)');
INSERT INTO crams_forcode (id, code, description) VALUES (968, '120503', 'Housing Markets, Development, Management');
INSERT INTO crams_forcode (id, code, description) VALUES (969, '120504', 'Land Use and Environmental Planning');
INSERT INTO crams_forcode (id, code, description) VALUES (970, '120505', 'Regional Analysis and Development');
INSERT INTO crams_forcode (id, code, description) VALUES (971, '120506', 'Transport Planning');
INSERT INTO crams_forcode (id, code, description) VALUES (972, '120507', 'Urban Analysis and Development');
INSERT INTO crams_forcode (id, code, description) VALUES (973, '120508', 'Urban Design');
INSERT INTO crams_forcode (id, code, description) VALUES (974, '120599', 'Urban and Regional Planning not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (975, '129999', 'Built Environment and Design not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (976, '130101', 'Continuing and Community Education');
INSERT INTO crams_forcode (id, code, description) VALUES (977, '130102', 'Early Childhood Education (excl. Maori)');
INSERT INTO crams_forcode (id, code, description) VALUES (978, '130103', 'Higher Education');
INSERT INTO crams_forcode (id, code, description) VALUES (979, '130104', 'Kura Kaupapa Maori (Maori Primary Education)');
INSERT INTO crams_forcode (id, code, description) VALUES (980, '130105', 'Primary Education (excl. Maori)');
INSERT INTO crams_forcode (id, code, description) VALUES (981, '130106', 'Secondary Education');
INSERT INTO crams_forcode (id, code, description) VALUES (982, '130107', 'Te Whariki (Maori Early Childhood Education)');
INSERT INTO crams_forcode (id, code, description) VALUES (983, '130108', 'Technical, Further and Workplace Education');
INSERT INTO crams_forcode (id, code, description) VALUES (984, '130199', 'Education Systems not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (985, '130201', 'Creative Arts, Media and Communication Curriculum and Pedagogy');
INSERT INTO crams_forcode (id, code, description) VALUES (986, '130202', 'Curriculum and Pedagogy Theory and Development');
INSERT INTO crams_forcode (id, code, description) VALUES (987, '130203', 'Economics, Business and Management Curriculum and Pedagogy');
INSERT INTO crams_forcode (id, code, description) VALUES (988, '130204', 'English and Literacy Curriculum and Pedagogy (excl. LOTE, ESL and TESOL)');
INSERT INTO crams_forcode (id, code, description) VALUES (989, '130205', 'Humanities and Social Sciences Curriculum and Pedagogy (excl. Economics, Business and Management)');
INSERT INTO crams_forcode (id, code, description) VALUES (990, '130206', 'Khdhanga Reo (Maori Language Curriculum and Pedagogy)');
INSERT INTO crams_forcode (id, code, description) VALUES (991, '130207', 'LOTE, ESL and TESOL Curriculum and Pedagogy (excl. Maori)');
INSERT INTO crams_forcode (id, code, description) VALUES (992, '130208', 'Mathematics and Numeracy Curriculum and Pedagogy');
INSERT INTO crams_forcode (id, code, description) VALUES (993, '130209', 'Medicine, Nursing and Health Curriculum and Pedagogy');
INSERT INTO crams_forcode (id, code, description) VALUES (994, '130210', 'Physical Education and Development Curriculum and Pedagogy');
INSERT INTO crams_forcode (id, code, description) VALUES (995, '130211', 'Religion Curriculum and Pedagogy');
INSERT INTO crams_forcode (id, code, description) VALUES (996, '130212', 'Science, Technology and Engineering Curriculum and Pedagogy');
INSERT INTO crams_forcode (id, code, description) VALUES (997, '130213', 'Vocational Education and Training Curriculum and Pedagogy');
INSERT INTO crams_forcode (id, code, description) VALUES (998, '130299', 'Curriculum and Pedagogy not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (999, '130301', 'Aboriginal and Torres Strait Islander Education');
INSERT INTO crams_forcode (id, code, description) VALUES (1000, '130302', 'Comparative and Cross-Cultural Education');
INSERT INTO crams_forcode (id, code, description) VALUES (1001, '130303', 'Education Assessment and Evaluation');
INSERT INTO crams_forcode (id, code, description) VALUES (1002, '130304', 'Educational Administration, Management and Leadership');
INSERT INTO crams_forcode (id, code, description) VALUES (1003, '130305', 'Educational Counselling');
INSERT INTO crams_forcode (id, code, description) VALUES (1004, '130306', 'Educational Technology and Computing');
INSERT INTO crams_forcode (id, code, description) VALUES (1005, '130307', 'Ethnic Education (excl. Aboriginal and Torres Strait Islander, Maori and Pacific Peoples)');
INSERT INTO crams_forcode (id, code, description) VALUES (1006, '130308', 'Gender, Sexuality and Education');
INSERT INTO crams_forcode (id, code, description) VALUES (1007, '130309', 'Learning Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (1008, '130310', 'Maori Education (excl. Early Childhood and Primary Education)');
INSERT INTO crams_forcode (id, code, description) VALUES (1009, '130311', 'Pacific Peoples Education');
INSERT INTO crams_forcode (id, code, description) VALUES (1010, '130312', 'Special Education and Disability');
INSERT INTO crams_forcode (id, code, description) VALUES (1011, '130313', 'Teacher Education and Professional Development of Educators');
INSERT INTO crams_forcode (id, code, description) VALUES (1012, '130399', 'Specialist Studies in Education not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1013, '139999', 'Education not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1014, '140101', 'History of Economic Thought');
INSERT INTO crams_forcode (id, code, description) VALUES (1015, '140102', 'Macroeconomic Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1016, '140103', 'Mathematical Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1017, '140104', 'Microeconomic Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1018, '140199', 'Economic Theory not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1019, '140201', 'Agricultural Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1020, '140202', 'Economic Development and Growth');
INSERT INTO crams_forcode (id, code, description) VALUES (1021, '140203', 'Economic History');
INSERT INTO crams_forcode (id, code, description) VALUES (1022, '140204', 'Economics of Education');
INSERT INTO crams_forcode (id, code, description) VALUES (1023, '140205', 'Environment and Resource Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1024, '140206', 'Experimental Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1025, '140207', 'Financial Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1026, '140208', 'Health Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1027, '140209', 'Industry Economics and Industrial Organisation');
INSERT INTO crams_forcode (id, code, description) VALUES (1028, '140210', 'International Economics and International Finance');
INSERT INTO crams_forcode (id, code, description) VALUES (1029, '140211', 'Labour Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1030, '140212', 'Macroeconomics (incl. Monetary and Fiscal Theory)');
INSERT INTO crams_forcode (id, code, description) VALUES (1031, '140213', 'Public Economics- Public Choice');
INSERT INTO crams_forcode (id, code, description) VALUES (1032, '140214', 'Public Economics- Publically Provided Goods');
INSERT INTO crams_forcode (id, code, description) VALUES (1033, '140215', 'Public Economics- Taxation and Revenue');
INSERT INTO crams_forcode (id, code, description) VALUES (1034, '140216', 'Tourism Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1035, '140217', 'Transport Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1036, '140218', 'Urban and Regional Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1037, '140219', 'Welfare Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1038, '140299', 'Applied Economics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1039, '140301', 'Cross-Sectional Analysis');
INSERT INTO crams_forcode (id, code, description) VALUES (1040, '140302', 'Econometric and Statistical Methods');
INSERT INTO crams_forcode (id, code, description) VALUES (1041, '140303', 'Economic Models and Forecasting');
INSERT INTO crams_forcode (id, code, description) VALUES (1042, '140304', 'Panel Data Analysis');
INSERT INTO crams_forcode (id, code, description) VALUES (1043, '140305', 'Time-Series Analysis');
INSERT INTO crams_forcode (id, code, description) VALUES (1044, '140399', 'Econometrics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1045, '149901', 'Comparative Economic Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (1046, '149902', 'Ecological Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1047, '149903', 'Heterodox Economics');
INSERT INTO crams_forcode (id, code, description) VALUES (1048, '149999', 'Economics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1049, '150101', 'Accounting Theory and Standards');
INSERT INTO crams_forcode (id, code, description) VALUES (1050, '150102', 'Auditing and Accountability');
INSERT INTO crams_forcode (id, code, description) VALUES (1051, '150103', 'Financial Accounting');
INSERT INTO crams_forcode (id, code, description) VALUES (1052, '150104', 'International Accounting');
INSERT INTO crams_forcode (id, code, description) VALUES (1053, '150105', 'Management Accounting');
INSERT INTO crams_forcode (id, code, description) VALUES (1054, '150106', 'Sustainability Accounting and Reporting');
INSERT INTO crams_forcode (id, code, description) VALUES (1055, '150107', 'Taxation Accounting');
INSERT INTO crams_forcode (id, code, description) VALUES (1056, '150199', 'Accounting, Auditing and Accountability not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1057, '150201', 'Finance');
INSERT INTO crams_forcode (id, code, description) VALUES (1058, '150202', 'Financial Econometrics');
INSERT INTO crams_forcode (id, code, description) VALUES (1059, '150203', 'Financial Institutions (incl. Banking)');
INSERT INTO crams_forcode (id, code, description) VALUES (1060, '150204', 'Insurance Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1061, '150205', 'Investment and Risk Management');
INSERT INTO crams_forcode (id, code, description) VALUES (1062, '150299', 'Banking, Finance and Investment not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1063, '150301', 'Business Information Management (incl. Records, Knowledge and Information Management, and Intelligence)');
INSERT INTO crams_forcode (id, code, description) VALUES (1064, '150302', 'Business Information Systems');
INSERT INTO crams_forcode (id, code, description) VALUES (1065, '150303', 'Corporate Governance and Stakeholder Engagement');
INSERT INTO crams_forcode (id, code, description) VALUES (1066, '150304', 'Entrepreneurship');
INSERT INTO crams_forcode (id, code, description) VALUES (1069, '150307', 'Innovation and Technology Management');
INSERT INTO crams_forcode (id, code, description) VALUES (1070, '150308', 'International Business');
INSERT INTO crams_forcode (id, code, description) VALUES (1071, '150309', 'Logistics and Supply Chain Management');
INSERT INTO crams_forcode (id, code, description) VALUES (1072, '150310', 'Organisation and Management Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1073, '150311', 'Organisational Behaviour');
INSERT INTO crams_forcode (id, code, description) VALUES (1074, '150312', 'Organisational Planning and Management');
INSERT INTO crams_forcode (id, code, description) VALUES (1075, '150313', 'Quality Management');
INSERT INTO crams_forcode (id, code, description) VALUES (1076, '150314', 'Small Business Management');
INSERT INTO crams_forcode (id, code, description) VALUES (1077, '150399', 'Business and Management not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1078, '150401', 'Food and Hospitality Services');
INSERT INTO crams_forcode (id, code, description) VALUES (1079, '150402', 'Hospitality Management');
INSERT INTO crams_forcode (id, code, description) VALUES (1080, '150403', 'Real Estate and Valuation Services');
INSERT INTO crams_forcode (id, code, description) VALUES (1081, '150404', 'Sport and Leisure Management');
INSERT INTO crams_forcode (id, code, description) VALUES (1082, '150499', 'Commercial Services not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1083, '150501', 'Consumer-Oriented Product or Service Development');
INSERT INTO crams_forcode (id, code, description) VALUES (1084, '150502', 'Marketing Communications');
INSERT INTO crams_forcode (id, code, description) VALUES (1085, '150503', 'Marketing Management (incl. Strategy and Customer Relations)');
INSERT INTO crams_forcode (id, code, description) VALUES (1086, '150504', 'Marketing Measurement');
INSERT INTO crams_forcode (id, code, description) VALUES (1087, '150505', 'Marketing Research Methodology');
INSERT INTO crams_forcode (id, code, description) VALUES (1088, '150506', 'Marketing Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1089, '150507', 'Pricing (incl. Consumer Value Estimation)');
INSERT INTO crams_forcode (id, code, description) VALUES (1090, '150599', 'Marketing not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1091, '150601', 'Impacts of Tourism');
INSERT INTO crams_forcode (id, code, description) VALUES (1092, '150602', 'Tourism Forecasting');
INSERT INTO crams_forcode (id, code, description) VALUES (1093, '150603', 'Tourism Management');
INSERT INTO crams_forcode (id, code, description) VALUES (1094, '150604', 'Tourism Marketing');
INSERT INTO crams_forcode (id, code, description) VALUES (1095, '150605', 'Tourism Resource Appraisal');
INSERT INTO crams_forcode (id, code, description) VALUES (1096, '150606', 'Tourist Behaviour and Visitor Experience');
INSERT INTO crams_forcode (id, code, description) VALUES (1097, '150699', 'Tourism not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1098, '150701', 'Air Transportation and Freight Services');
INSERT INTO crams_forcode (id, code, description) VALUES (1099, '150702', 'Rail Transportation and Freight Services');
INSERT INTO crams_forcode (id, code, description) VALUES (1100, '150703', 'Road Transportation and Freight Services');
INSERT INTO crams_forcode (id, code, description) VALUES (1101, '150799', 'Transportation and Freight Services not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1102, '159999', 'Commerce, Management, Tourism and Services not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1103, '160101', 'Anthropology of Development');
INSERT INTO crams_forcode (id, code, description) VALUES (1104, '160102', 'Biological (Physical) Anthropology');
INSERT INTO crams_forcode (id, code, description) VALUES (1105, '160103', 'Linguistic Anthropology');
INSERT INTO crams_forcode (id, code, description) VALUES (1106, '160104', 'Social and Cultural Anthropology');
INSERT INTO crams_forcode (id, code, description) VALUES (1107, '160199', 'Anthropology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1108, '160201', 'Causes and Prevention of Crime');
INSERT INTO crams_forcode (id, code, description) VALUES (1109, '160202', 'Correctional Theory, Offender Treatment and Rehabilitation');
INSERT INTO crams_forcode (id, code, description) VALUES (1110, '160203', 'Courts and Sentencing');
INSERT INTO crams_forcode (id, code, description) VALUES (1111, '160204', 'Criminological Theories');
INSERT INTO crams_forcode (id, code, description) VALUES (1112, '160205', 'Police Administration, Procedures and Practice');
INSERT INTO crams_forcode (id, code, description) VALUES (1113, '160206', 'Private Policing and Security Services');
INSERT INTO crams_forcode (id, code, description) VALUES (1114, '160299', 'Criminology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1115, '160301', 'Family and Household Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1116, '160302', 'Fertility');
INSERT INTO crams_forcode (id, code, description) VALUES (1117, '160303', 'Migration');
INSERT INTO crams_forcode (id, code, description) VALUES (1118, '160304', 'Mortality');
INSERT INTO crams_forcode (id, code, description) VALUES (1119, '160305', 'Population Trends and Policies');
INSERT INTO crams_forcode (id, code, description) VALUES (1120, '160399', 'Demography not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1121, '160401', 'Economic Geography');
INSERT INTO crams_forcode (id, code, description) VALUES (1122, '160402', 'Recreation, Leisure and Tourism Geography');
INSERT INTO crams_forcode (id, code, description) VALUES (1123, '160403', 'Social and Cultural Geography');
INSERT INTO crams_forcode (id, code, description) VALUES (1124, '160404', 'Urban and Regional Studies (excl. Planning)');
INSERT INTO crams_forcode (id, code, description) VALUES (1125, '160499', 'Human Geography not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1126, '160501', 'Aboriginal and Torres Strait Islander Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1127, '160502', 'Arts and Cultural Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1128, '160503', 'Communications and Media Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1129, '160504', 'Crime Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1130, '160505', 'Economic Development Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1131, '160506', 'Education Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1132, '160507', 'Environment Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1133, '160508', 'Health Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1134, '160509', 'Public Administration');
INSERT INTO crams_forcode (id, code, description) VALUES (1135, '160510', 'Public Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1136, '160511', 'Research, Science and Technology Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1137, '160512', 'Social Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1138, '160513', 'Tourism Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1139, '160514', 'Urban Policy');
INSERT INTO crams_forcode (id, code, description) VALUES (1140, '160599', 'Policy and Administration not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1141, '160601', 'Australian Government and Politics');
INSERT INTO crams_forcode (id, code, description) VALUES (1142, '160602', 'Citizenship');
INSERT INTO crams_forcode (id, code, description) VALUES (1143, '160603', 'Comparative Government and Politics');
INSERT INTO crams_forcode (id, code, description) VALUES (1144, '160604', 'Defence Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1145, '160605', 'Environmental Politics');
INSERT INTO crams_forcode (id, code, description) VALUES (1146, '160606', 'Government and Politics of Asia and the Pacific');
INSERT INTO crams_forcode (id, code, description) VALUES (1147, '160607', 'International Relations');
INSERT INTO crams_forcode (id, code, description) VALUES (1148, '160608', 'New Zealand Government and Politics');
INSERT INTO crams_forcode (id, code, description) VALUES (1149, '160609', 'Political Theory and Political Philosophy');
INSERT INTO crams_forcode (id, code, description) VALUES (1150, '160699', 'Political Science not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1151, '160701', 'Clinical Social Work Practice');
INSERT INTO crams_forcode (id, code, description) VALUES (1152, '160702', 'Counselling, Welfare and Community Services');
INSERT INTO crams_forcode (id, code, description) VALUES (1153, '160703', 'Social Program Evaluation');
INSERT INTO crams_forcode (id, code, description) VALUES (1154, '160799', 'Social Work not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1155, '160801', 'Applied Sociology, Program Evaluation and Social Impact Assessment');
INSERT INTO crams_forcode (id, code, description) VALUES (1156, '160802', 'Environmental Sociology');
INSERT INTO crams_forcode (id, code, description) VALUES (1157, '160803', 'Race and Ethnic Relations');
INSERT INTO crams_forcode (id, code, description) VALUES (1158, '160804', 'Rural Sociology');
INSERT INTO crams_forcode (id, code, description) VALUES (1159, '160805', 'Social Change');
INSERT INTO crams_forcode (id, code, description) VALUES (1160, '160806', 'Social Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1161, '160807', 'Sociological Methodology and Research Methods');
INSERT INTO crams_forcode (id, code, description) VALUES (1162, '160808', 'Sociology and Social Studies of Science and Technology');
INSERT INTO crams_forcode (id, code, description) VALUES (1163, '160809', 'Sociology of Education');
INSERT INTO crams_forcode (id, code, description) VALUES (1164, '160810', 'Urban Sociology and Community Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1165, '160899', 'Sociology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1166, '169901', 'Gender Specific Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1167, '169902', 'Studies of Aboriginal and Torres Strait Islander Society');
INSERT INTO crams_forcode (id, code, description) VALUES (1168, '169903', 'Studies of Asian Society');
INSERT INTO crams_forcode (id, code, description) VALUES (1169, '169904', 'Studies of Maori Society');
INSERT INTO crams_forcode (id, code, description) VALUES (1170, '169905', 'Studies of Pacific Peoples'' Societies');
INSERT INTO crams_forcode (id, code, description) VALUES (1171, '169999', 'Studies in Human Society not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1172, '170101', 'Biological Psychology (Neuropsychology, Psychopharmacology, Physiological Psychology)');
INSERT INTO crams_forcode (id, code, description) VALUES (1173, '170102', 'Developmental Psychology and Ageing');
INSERT INTO crams_forcode (id, code, description) VALUES (1174, '170103', 'Educational Psychology');
INSERT INTO crams_forcode (id, code, description) VALUES (1175, '170104', 'Forensic Psychology');
INSERT INTO crams_forcode (id, code, description) VALUES (1176, '170105', 'Gender Psychology');
INSERT INTO crams_forcode (id, code, description) VALUES (1177, '170106', 'Health, Clinical and Counselling Psychology');
INSERT INTO crams_forcode (id, code, description) VALUES (1178, '170107', 'Industrial and Organisational Psychology');
INSERT INTO crams_forcode (id, code, description) VALUES (1179, '170108', 'Kaupapa Maori Psychology');
INSERT INTO crams_forcode (id, code, description) VALUES (1180, '170109', 'Personality, Abilities and Assessment');
INSERT INTO crams_forcode (id, code, description) VALUES (1181, '170110', 'Psychological Methodology, Design and Analysis');
INSERT INTO crams_forcode (id, code, description) VALUES (1182, '170111', 'Psychology of Religion');
INSERT INTO crams_forcode (id, code, description) VALUES (1183, '170112', 'Sensory Processes, Perception and Performance');
INSERT INTO crams_forcode (id, code, description) VALUES (1184, '170113', 'Social and Community Psychology');
INSERT INTO crams_forcode (id, code, description) VALUES (1185, '170114', 'Sport and Exercise Psychology');
INSERT INTO crams_forcode (id, code, description) VALUES (1186, '170199', 'Psychology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1187, '170201', 'Computer Perception, Memory and Attention');
INSERT INTO crams_forcode (id, code, description) VALUES (1188, '170202', 'Decision Making');
INSERT INTO crams_forcode (id, code, description) VALUES (1189, '170203', 'Knowledge Representation and Machine Learning');
INSERT INTO crams_forcode (id, code, description) VALUES (1190, '170204', 'Linguistic Processes (incl. Speech Production and Comprehension)');
INSERT INTO crams_forcode (id, code, description) VALUES (1191, '170205', 'Neurocognitive Patterns and Neural Networks');
INSERT INTO crams_forcode (id, code, description) VALUES (1192, '170299', 'Cognitive Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1193, '179999', 'Psychology and Cognitive Sciences not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1194, '180101', 'Aboriginal and Torres Strait Islander Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1195, '180102', 'Access to Justice');
INSERT INTO crams_forcode (id, code, description) VALUES (1196, '180103', 'Administrative Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1197, '180104', 'Civil Law and Procedure');
INSERT INTO crams_forcode (id, code, description) VALUES (1198, '180105', 'Commercial and Contract Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1199, '180106', 'Comparative Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1200, '180107', 'Conflict of Laws (Private International Law)');
INSERT INTO crams_forcode (id, code, description) VALUES (1201, '180108', 'Constitutional Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1202, '180109', 'Corporations and Associations Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1203, '180110', 'Criminal Law and Procedure');
INSERT INTO crams_forcode (id, code, description) VALUES (1204, '180111', 'Environmental and Natural Resources Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1205, '180112', 'Equity and Trusts Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1206, '180113', 'Family Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1207, '180114', 'Human Rights Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1208, '180115', 'Intellectual Property Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1209, '180116', 'International Law (excl. International Trade Law)');
INSERT INTO crams_forcode (id, code, description) VALUES (1210, '180117', 'International Trade Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1211, '180118', 'Labour Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1212, '180119', 'Law and Society');
INSERT INTO crams_forcode (id, code, description) VALUES (1213, '180120', 'Legal Institutions (incl. Courts and Justice Systems)');
INSERT INTO crams_forcode (id, code, description) VALUES (1214, '180121', 'Legal Practice, Lawyering and the Legal Profession');
INSERT INTO crams_forcode (id, code, description) VALUES (1215, '180122', 'Legal Theory, Jurisprudence and Legal Interpretation');
INSERT INTO crams_forcode (id, code, description) VALUES (1216, '180123', 'Litigation, Adjudication and Dispute Resolution');
INSERT INTO crams_forcode (id, code, description) VALUES (1217, '180124', 'Property Law (excl. Intellectual Property Law)');
INSERT INTO crams_forcode (id, code, description) VALUES (1218, '180125', 'Taxation Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1219, '180126', 'Tort Law');
INSERT INTO crams_forcode (id, code, description) VALUES (1220, '180199', 'Law not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1221, '180201', 'Nga Tikanga Maori (Maori Customary Law)');
INSERT INTO crams_forcode (id, code, description) VALUES (1222, '180202', 'Te Maori Whakakaere Rauemi (Maori Resource Law)');
INSERT INTO crams_forcode (id, code, description) VALUES (1223, '180203', 'Te Tiriti O Waitangi (The Treaty of Waitangi)');
INSERT INTO crams_forcode (id, code, description) VALUES (1224, '180204', 'Te Ture Whenua (Maori Land Law)');
INSERT INTO crams_forcode (id, code, description) VALUES (1225, '180299', 'Maori Law not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1226, '189999', 'Law and Legal Studies not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1227, '190101', 'Art Criticism');
INSERT INTO crams_forcode (id, code, description) VALUES (1228, '190102', 'Art History');
INSERT INTO crams_forcode (id, code, description) VALUES (1229, '190103', 'Art Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1230, '190104', 'Visual Cultures');
INSERT INTO crams_forcode (id, code, description) VALUES (1231, '190199', 'Art Theory and Criticism not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1232, '190201', 'Cinema Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1233, '190202', 'Computer Gaming and Animation');
INSERT INTO crams_forcode (id, code, description) VALUES (1234, '190203', 'Electronic Media Art');
INSERT INTO crams_forcode (id, code, description) VALUES (1235, '190204', 'Film and Television');
INSERT INTO crams_forcode (id, code, description) VALUES (1236, '190205', 'Interactive Media');
INSERT INTO crams_forcode (id, code, description) VALUES (1237, '190299', 'Film, Television and Digital Media not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1238, '190301', 'Journalism Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1239, '190302', 'Professional Writing');
INSERT INTO crams_forcode (id, code, description) VALUES (1240, '190303', 'Technical Writing');
INSERT INTO crams_forcode (id, code, description) VALUES (1241, '190399', 'Journalism and Professional Writing not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1242, '190401', 'Aboriginal and Torres Strait Islander Performing Arts');
INSERT INTO crams_forcode (id, code, description) VALUES (1243, '190402', 'Creative Writing (incl. Playwriting)');
INSERT INTO crams_forcode (id, code, description) VALUES (1244, '190403', 'Dance');
INSERT INTO crams_forcode (id, code, description) VALUES (1245, '190404', 'Drama, Theatre and Performance Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1246, '190405', 'Maori Performing Arts');
INSERT INTO crams_forcode (id, code, description) VALUES (1247, '190406', 'Music Composition');
INSERT INTO crams_forcode (id, code, description) VALUES (1248, '190407', 'Music Performance');
INSERT INTO crams_forcode (id, code, description) VALUES (1249, '190408', 'Music Therapy');
INSERT INTO crams_forcode (id, code, description) VALUES (1250, '190409', 'Musicology and Ethnomusicology');
INSERT INTO crams_forcode (id, code, description) VALUES (1251, '190410', 'Pacific Peoples Performing Arts');
INSERT INTO crams_forcode (id, code, description) VALUES (1252, '190499', 'Performing Arts and Creative Writing not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1253, '190501', 'Crafts');
INSERT INTO crams_forcode (id, code, description) VALUES (1254, '190502', 'Fine Arts (incl. Sculpture and Painting)');
INSERT INTO crams_forcode (id, code, description) VALUES (1255, '190503', 'Lens-based Practice');
INSERT INTO crams_forcode (id, code, description) VALUES (1256, '190504', 'Performance and Installation Art');
INSERT INTO crams_forcode (id, code, description) VALUES (1257, '190599', 'Visual Arts and Crafts not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1258, '199999', 'Studies in Creative Arts and Writing not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1259, '200101', 'Communication Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1260, '200102', 'Communication Technology and Digital Media Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1261, '200103', 'International and Development Communication');
INSERT INTO crams_forcode (id, code, description) VALUES (1262, '200104', 'Media Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1263, '200105', 'Organisational, Interpersonal and Intercultural Communication');
INSERT INTO crams_forcode (id, code, description) VALUES (1264, '200199', 'Communication and Media Studies not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1265, '200201', 'Aboriginal and Torres Strait Islander Cultural Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1266, '200202', 'Asian Cultural Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1267, '200203', 'Consumption and Everyday Life');
INSERT INTO crams_forcode (id, code, description) VALUES (1268, '200204', 'Cultural Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1269, '200205', 'Culture, Gender, Sexuality');
INSERT INTO crams_forcode (id, code, description) VALUES (1270, '200206', 'Globalisation and Culture');
INSERT INTO crams_forcode (id, code, description) VALUES (1271, '200207', 'Maori Cultural Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1272, '200208', 'Migrant Cultural Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1273, '200209', 'Multicultural, Intercultural and Cross-cultural Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1274, '200210', 'Pacific Cultural Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1275, '200211', 'Postcolonial Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1276, '200212', 'Screen and Media Culture');
INSERT INTO crams_forcode (id, code, description) VALUES (1277, '200299', 'Cultural Studies not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1278, '200301', 'Early English Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (1279, '200302', 'English Language');
INSERT INTO crams_forcode (id, code, description) VALUES (1280, '200303', 'English as a Second Language');
INSERT INTO crams_forcode (id, code, description) VALUES (1281, '200304', 'Central and Eastern European Languages (incl. Russian)');
INSERT INTO crams_forcode (id, code, description) VALUES (1282, '200305', 'Latin and Classical Greek Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (1283, '200306', 'French Language');
INSERT INTO crams_forcode (id, code, description) VALUES (1284, '200307', 'German Language');
INSERT INTO crams_forcode (id, code, description) VALUES (1285, '200308', 'Iberian Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (1286, '200309', 'Italian Language');
INSERT INTO crams_forcode (id, code, description) VALUES (1287, '200310', 'Other European Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (1288, '200311', 'Chinese Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (1289, '200312', 'Japanese Language');
INSERT INTO crams_forcode (id, code, description) VALUES (1290, '200313', 'Indonesian Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (1291, '200314', 'South-East Asian Languages (excl. Indonesian)');
INSERT INTO crams_forcode (id, code, description) VALUES (1292, '200315', 'Indian Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (1293, '200316', 'Korean Language');
INSERT INTO crams_forcode (id, code, description) VALUES (1294, '200317', 'Other Asian Languages (excl. South-East Asian)');
INSERT INTO crams_forcode (id, code, description) VALUES (1295, '200318', 'Middle Eastern Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (1296, '200319', 'Aboriginal and Torres Strait Islander Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (1297, '200320', 'Pacific Languages');
INSERT INTO crams_forcode (id, code, description) VALUES (1298, '200321', 'Te Reo Maori (Maori Language)');
INSERT INTO crams_forcode (id, code, description) VALUES (1299, '200322', 'Comparative Language Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1300, '200323', 'Translation and Interpretation Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1301, '200399', 'Language Studies not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1302, '200401', 'Applied Linguistics and Educational Linguistics');
INSERT INTO crams_forcode (id, code, description) VALUES (1303, '200402', 'Computational Linguistics');
INSERT INTO crams_forcode (id, code, description) VALUES (1304, '200403', 'Discourse and Pragmatics');
INSERT INTO crams_forcode (id, code, description) VALUES (1305, '200404', 'Laboratory Phonetics and Speech Science');
INSERT INTO crams_forcode (id, code, description) VALUES (1306, '200405', 'Language in Culture and Society (Sociolinguistics)');
INSERT INTO crams_forcode (id, code, description) VALUES (1307, '200406', 'Language in Time and Space (incl. Historical Linguistics, Dialectology)');
INSERT INTO crams_forcode (id, code, description) VALUES (1308, '200407', 'Lexicography');
INSERT INTO crams_forcode (id, code, description) VALUES (1309, '200408', 'Linguistic Structures (incl. Grammar, Phonology, Lexicon, Semantics)');
INSERT INTO crams_forcode (id, code, description) VALUES (1310, '200499', 'Linguistics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1311, '200501', 'Aboriginal and Torres Strait Islander Literature');
INSERT INTO crams_forcode (id, code, description) VALUES (1312, '200502', 'Australian Literature (excl. Aboriginal and Torres Strait Islander Literature)');
INSERT INTO crams_forcode (id, code, description) VALUES (1313, '200503', 'British and Irish Literature');
INSERT INTO crams_forcode (id, code, description) VALUES (1314, '200504', 'Maori Literature');
INSERT INTO crams_forcode (id, code, description) VALUES (1315, '200505', 'New Zealand Literature (excl. Maori Literature)');
INSERT INTO crams_forcode (id, code, description) VALUES (1316, '200506', 'North American Literature');
INSERT INTO crams_forcode (id, code, description) VALUES (1317, '200507', 'Pacific Literature');
INSERT INTO crams_forcode (id, code, description) VALUES (1318, '200508', 'Other Literatures in English');
INSERT INTO crams_forcode (id, code, description) VALUES (1319, '200509', 'Central and Eastern European Literature (incl. Russian)');
INSERT INTO crams_forcode (id, code, description) VALUES (1320, '200510', 'Latin and Classical Greek Literature');
INSERT INTO crams_forcode (id, code, description) VALUES (1321, '200511', 'Literature in French');
INSERT INTO crams_forcode (id, code, description) VALUES (1322, '200512', 'Literature in German');
INSERT INTO crams_forcode (id, code, description) VALUES (1323, '200513', 'Literature in Italian');
INSERT INTO crams_forcode (id, code, description) VALUES (1324, '200514', 'Literature in Spanish and Portuguese');
INSERT INTO crams_forcode (id, code, description) VALUES (1325, '200515', 'Other European Literature');
INSERT INTO crams_forcode (id, code, description) VALUES (1326, '200516', 'Indonesian Literature');
INSERT INTO crams_forcode (id, code, description) VALUES (1327, '200517', 'Literature in Chinese');
INSERT INTO crams_forcode (id, code, description) VALUES (1328, '200518', 'Literature in Japanese');
INSERT INTO crams_forcode (id, code, description) VALUES (1329, '200519', 'South-East Asian Literature (excl. Indonesian)');
INSERT INTO crams_forcode (id, code, description) VALUES (1330, '200520', 'Indian Literature');
INSERT INTO crams_forcode (id, code, description) VALUES (1331, '200521', 'Korean Literature');
INSERT INTO crams_forcode (id, code, description) VALUES (1332, '200522', 'Other Asian Literature (excl. South-East Asian)');
INSERT INTO crams_forcode (id, code, description) VALUES (1333, '200523', 'Middle Eastern Literature');
INSERT INTO crams_forcode (id, code, description) VALUES (1334, '200524', 'Comparative Literature Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1335, '200525', 'Literary Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1336, '200526', 'Stylistics and Textual Analysis');
INSERT INTO crams_forcode (id, code, description) VALUES (1337, '200599', 'Literary Studies not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1338, '209999', 'Language, Communication and Culture not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1339, '210101', 'Aboriginal and Torres Strait Islander Archaeology');
INSERT INTO crams_forcode (id, code, description) VALUES (1340, '210102', 'Archaeological Science');
INSERT INTO crams_forcode (id, code, description) VALUES (1341, '210103', 'Archaeology of Asia, Africa and the Americas');
INSERT INTO crams_forcode (id, code, description) VALUES (1342, '210104', 'Archaeology of Australia (excl. Aboriginal and Torres Strait Islander)');
INSERT INTO crams_forcode (id, code, description) VALUES (1343, '210105', 'Archaeology of Europe, the Mediterranean and the Levant');
INSERT INTO crams_forcode (id, code, description) VALUES (1344, '210106', 'Archaeology of New Guinea and Pacific Islands (excl. New Zealand)');
INSERT INTO crams_forcode (id, code, description) VALUES (1345, '210107', 'Archaeology of New Zealand (excl. Maori)');
INSERT INTO crams_forcode (id, code, description) VALUES (1346, '210108', 'Historical Archaeology (incl. Industrial Archaeology)');
INSERT INTO crams_forcode (id, code, description) VALUES (1347, '210109', 'Maori Archaeology');
INSERT INTO crams_forcode (id, code, description) VALUES (1348, '210110', 'Maritime Archaeology');
INSERT INTO crams_forcode (id, code, description) VALUES (1349, '210199', 'Archaeology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1350, '210201', 'Archival, Repository and Related Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1351, '210202', 'Heritage and Cultural Conservation');
INSERT INTO crams_forcode (id, code, description) VALUES (1352, '210203', 'Materials Conservation');
INSERT INTO crams_forcode (id, code, description) VALUES (1353, '210204', 'Museum Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1354, '210299', 'Curatorial and Related Studies not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1355, '210301', 'Aboriginal and Torres Strait Islander History');
INSERT INTO crams_forcode (id, code, description) VALUES (1356, '210302', 'Asian History');
INSERT INTO crams_forcode (id, code, description) VALUES (1357, '210303', 'Australian History (excl. Aboriginal and Torres Strait Islander History)');
INSERT INTO crams_forcode (id, code, description) VALUES (1358, '210304', 'Biography');
INSERT INTO crams_forcode (id, code, description) VALUES (1359, '210305', 'British History');
INSERT INTO crams_forcode (id, code, description) VALUES (1360, '210306', 'Classical Greek and Roman History');
INSERT INTO crams_forcode (id, code, description) VALUES (1361, '210307', 'European History (excl. British, Classical Greek and Roman)');
INSERT INTO crams_forcode (id, code, description) VALUES (1362, '210308', 'Latin American History');
INSERT INTO crams_forcode (id, code, description) VALUES (1363, '210309', 'Maori History');
INSERT INTO crams_forcode (id, code, description) VALUES (1364, '210310', 'Middle Eastern and African History');
INSERT INTO crams_forcode (id, code, description) VALUES (1365, '210311', 'New Zealand History');
INSERT INTO crams_forcode (id, code, description) VALUES (1366, '210312', 'North American History');
INSERT INTO crams_forcode (id, code, description) VALUES (1367, '210313', 'Pacific History (excl. New Zealand and Maori)');
INSERT INTO crams_forcode (id, code, description) VALUES (1368, '210399', 'Historical Studies not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1369, '219999', 'History and Archaeology not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1370, '220101', 'Bioethics (human and animal)');
INSERT INTO crams_forcode (id, code, description) VALUES (1371, '220102', 'Business Ethics');
INSERT INTO crams_forcode (id, code, description) VALUES (1372, '220103', 'Ethical Use of New Technology (e.g. Nanotechnology, Biotechnology)');
INSERT INTO crams_forcode (id, code, description) VALUES (1373, '220104', 'Human Rights and Justice Issues');
INSERT INTO crams_forcode (id, code, description) VALUES (1374, '220105', 'Legal Ethics');
INSERT INTO crams_forcode (id, code, description) VALUES (1375, '220106', 'Medical Ethics');
INSERT INTO crams_forcode (id, code, description) VALUES (1376, '220107', 'Professional Ethics (incl. police and research ethics)');
INSERT INTO crams_forcode (id, code, description) VALUES (1377, '220199', 'Applied Ethics not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1378, '220201', 'Business and Labour History');
INSERT INTO crams_forcode (id, code, description) VALUES (1379, '220202', 'History and Philosophy of Education');
INSERT INTO crams_forcode (id, code, description) VALUES (1380, '220203', 'History and Philosophy of Engineering and Technology');
INSERT INTO crams_forcode (id, code, description) VALUES (1381, '220204', 'History and Philosophy of Law and Justice');
INSERT INTO crams_forcode (id, code, description) VALUES (1382, '220205', 'History and Philosophy of Medicine');
INSERT INTO crams_forcode (id, code, description) VALUES (1383, '220206', 'History and Philosophy of Science (incl. Non-historical Philosophy of Science)');
INSERT INTO crams_forcode (id, code, description) VALUES (1384, '220207', 'History and Philosophy of the Humanities');
INSERT INTO crams_forcode (id, code, description) VALUES (1385, '220208', 'History and Philosophy of the Social Sciences');
INSERT INTO crams_forcode (id, code, description) VALUES (1386, '220209', 'History of Ideas');
INSERT INTO crams_forcode (id, code, description) VALUES (1387, '220210', 'History of Philosophy');
INSERT INTO crams_forcode (id, code, description) VALUES (1388, '220299', 'History and Philosophy of Specific Fields not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1389, '220301', 'Aesthetics');
INSERT INTO crams_forcode (id, code, description) VALUES (1390, '220302', 'Decision Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1391, '220303', 'Environmental Philosophy');
INSERT INTO crams_forcode (id, code, description) VALUES (1392, '220304', 'Epistemology');
INSERT INTO crams_forcode (id, code, description) VALUES (1393, '220305', 'Ethical Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1394, '220306', 'Feminist Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1395, '220307', 'Hermeneutic and Critical Theory');
INSERT INTO crams_forcode (id, code, description) VALUES (1396, '220308', 'Logic');
INSERT INTO crams_forcode (id, code, description) VALUES (1397, '220309', 'Metaphysics');
INSERT INTO crams_forcode (id, code, description) VALUES (1398, '220310', 'Phenomenology');
INSERT INTO crams_forcode (id, code, description) VALUES (1399, '220311', 'Philosophical Psychology (incl. Moral Psychology and Philosophy of Action)');
INSERT INTO crams_forcode (id, code, description) VALUES (1400, '220312', 'Philosophy of Cognition');
INSERT INTO crams_forcode (id, code, description) VALUES (1401, '220313', 'Philosophy of Language');
INSERT INTO crams_forcode (id, code, description) VALUES (1402, '220314', 'Philosophy of Mind (excl. Cognition)');
INSERT INTO crams_forcode (id, code, description) VALUES (1403, '220315', 'Philosophy of Religion');
INSERT INTO crams_forcode (id, code, description) VALUES (1404, '220316', 'Philosophy of Specific Cultures (incl. Comparative Philosophy)');
INSERT INTO crams_forcode (id, code, description) VALUES (1405, '220317', 'Poststructuralism');
INSERT INTO crams_forcode (id, code, description) VALUES (1406, '220318', 'Psychoanalytic Philosophy');
INSERT INTO crams_forcode (id, code, description) VALUES (1407, '220319', 'Social Philosophy');
INSERT INTO crams_forcode (id, code, description) VALUES (1408, '220399', 'Philosophy not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1409, '220401', 'Christian Studies (incl. Biblical Studies and Church History)');
INSERT INTO crams_forcode (id, code, description) VALUES (1410, '220402', 'Comparative Religious Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1411, '220403', 'Islamic Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1412, '220404', 'Jewish Studies');
INSERT INTO crams_forcode (id, code, description) VALUES (1413, '220405', 'Religion and Society');
INSERT INTO crams_forcode (id, code, description) VALUES (1414, '220406', 'Studies in Eastern Religious Traditions');
INSERT INTO crams_forcode (id, code, description) VALUES (1415, '220407', 'Studies in Religious Traditions (excl. Eastern, Jewish, Christian and Islamic Traditions)');
INSERT INTO crams_forcode (id, code, description) VALUES (1416, '220499', 'Religion and Religious Studies not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (1417, '229999', 'Philosophy and Religious Studies not elsewhere classified');
INSERT INTO crams_forcode (id, code, description) VALUES (999998,'999998', 'HPC Data Migration');
INSERT INTO crams_forcode (id, code, description) VALUES (999999, '999999', 'HPC Internal Operations');